@@ -31,20 +31,7 @@
 
 #include <gdk/gdkkeysyms.h>
 
-#include <gtk/gtkvbox.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkaction.h>
-#include <gtk/gtktoggleaction.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkcellrenderer.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtksizegroup.h>
+#include <gtk/gtk.h>
 
 #include "eggtreemultidnd.h"
 #include "baobab-cell-renderer-progress.h"
@@ -94,6 +81,8 @@ struct _BraseroDataDiscPrivate
 
 	GSList *load_errors;
 
+	gint size_changed_id;
+
 	guint loading;
 
 	guint editing:1;
@@ -134,7 +123,7 @@ static GtkActionEntry entries [] = {
 	 G_CALLBACK (brasero_data_disc_delete_activated_cb)},
 	{"PasteData", GTK_STOCK_PASTE, NULL, NULL, N_("Add the files stored in the clipboard"),
 	 G_CALLBACK (brasero_data_disc_paste_activated_cb)},
-	{"NewFolder", "folder-new", N_("New folder"), NULL, N_("Create a new empty folder"),
+	{"NewFolder", "folder-new", N_("New _Folder"), NULL, N_("Create a new empty folder"),
 	 G_CALLBACK (brasero_data_disc_new_folder_clicked_cb)},
 };
 
@@ -214,10 +203,10 @@ static void
 brasero_data_disc_import_failure_dialog (BraseroDataDisc *disc,
 					 GError *error)
 {
-	brasero_utils_message_dialog (gtk_widget_get_toplevel (GTK_WIDGET (disc)),
-				      _("The session couldn't be imported:"),
-				      error?error->message:_("unknown error"),
-				      GTK_MESSAGE_WARNING);
+	brasero_app_alert (brasero_app_get_default (),
+			   _("The session could not be imported."),
+			   error?error->message:_("An unknown error occured"),
+			   GTK_MESSAGE_WARNING);
 }
 
 static gboolean
@@ -611,7 +600,7 @@ brasero_data_disc_project_oversized_cb (BraseroDataProject *project,
 		message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message),
 						      _("Would you like to burn beyond the disc reported capacity?"),
 						      _("The size of the project is too large for the disc and you must remove files from the project otherwise."
-							"\nYou may want to use this option if you're using 90 or 100 min CD-R(W) which can't be properly recognised and therefore need overburn option."
+							"\nYou may want to use this option if you're using 90 or 100 min CD-R(W) which cannot be properly recognised and therefore need overburn option."
 							"\nNOTE: This option might cause failure."),
 						      -1,
 						      BRASERO_NOTIFY_CONTEXT_SIZE);
@@ -624,7 +613,7 @@ brasero_data_disc_project_oversized_cb (BraseroDataProject *project,
 					   GTK_RESPONSE_OK);
 		brasero_notify_button_add (BRASERO_NOTIFY (priv->message),
 					   BRASERO_DISC_MESSAGE (message),
-					   _("_Cancel"),
+					   GTK_STOCK_CANCEL,
 					   _("Click here not to use overburning"),
 					   GTK_RESPONSE_CANCEL);
 		
@@ -753,21 +742,16 @@ static gboolean
 brasero_data_disc_switch_to_image (gpointer data)
 {
 	GtkWidget *manager;
-	GtkWidget *toplevel;
 	BraseroDataDiscPrivate *priv;
 	BraseroDataDiscProjectSwitch *callback_data = data;
 
 	priv = BRASERO_DATA_DISC_PRIVATE (callback_data->disc);
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (callback_data->disc));
-	if (!BRASERO_IS_APP (toplevel))
-		return BRASERO_BURN_OK;
-
 	/* Clean up everything to avoid warning dialog */
 	brasero_data_project_reset (priv->project);
 
 	/* Tell project manager to switch */
-	manager = brasero_app_get_project_manager (BRASERO_APP (toplevel));
+	manager = brasero_app_get_project_manager (brasero_app_get_default ());
 	brasero_project_manager_iso (BRASERO_PROJECT_MANAGER (manager),
 				     callback_data->uri);
 
@@ -781,9 +765,9 @@ brasero_data_disc_image_uri_cb (BraseroDataVFS *vfs,
 {
 	gint answer;
 	gchar *name;
+	gchar *string;
 	GtkWidget *button;
 	GtkWidget *dialog;
-	GtkWidget *toplevel;
 	BraseroDataDiscPrivate *priv;
 	BraseroDataDiscProjectSwitch *callback_data;
 
@@ -792,24 +776,19 @@ brasero_data_disc_image_uri_cb (BraseroDataVFS *vfs,
 	if (priv->loading)
 		return BRASERO_BURN_OK;
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
-	if (!BRASERO_IS_APP (toplevel))
-		return BRASERO_BURN_OK;
-
 	name = brasero_file_node_get_uri_name (uri);
-	dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-					 GTK_DIALOG_DESTROY_WITH_PARENT |
-					 GTK_DIALOG_MODAL,
-					 GTK_MESSAGE_QUESTION,
-					 GTK_BUTTONS_NONE,
-					 _("Do you want to burn \"%s\" to a disc or add it in to the data project?"),
-					 name);
+	string = g_strdup_printf (_("Do you want to burn \"%s\" to a disc or add it in to the data project?"), name);
+	dialog = brasero_app_dialog (brasero_app_get_default (),
+				     string,
+				     GTK_BUTTONS_NONE,
+				     GTK_MESSAGE_QUESTION);
+	g_free (string);
 	g_free (name);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 						  _("This file is the image of a disc and can therefore be burnt to disc without having to add it to a data project first."));
 
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Add to project"), GTK_RESPONSE_NO);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Add to Project"), GTK_RESPONSE_NO);
 
 	button = brasero_utils_make_button (_("_Burn..."),
 					    NULL,
@@ -894,11 +873,11 @@ brasero_data_disc_unreadable_uri_cb (BraseroDataVFS *vfs,
 		return;
 	}
 
-	primary = g_strdup_printf (_("\"%s\" cannot be added to the selection:"), name);
-	brasero_utils_message_dialog (gtk_widget_get_toplevel (GTK_WIDGET (self)),
-				      primary,
-				      error->message,
-				      GTK_MESSAGE_ERROR);
+	primary = g_strdup_printf (_("\"%s\" cannot be added to the selection."), name);
+	brasero_app_alert (brasero_app_get_default (),
+			   primary,
+			   error->message,
+			   GTK_MESSAGE_ERROR);
 	g_free (primary);
 	g_free (name);
 }
@@ -925,11 +904,11 @@ brasero_data_disc_recursive_uri_cb (BraseroDataVFS *vfs,
 		return;
 	}
 
-	primary = g_strdup_printf (_("\"%s\" cannot be added to the selection:"), name);
-	brasero_utils_message_dialog (gtk_widget_get_toplevel (GTK_WIDGET (self)),
-				      primary,
-				      _("it is a recursive symlink."),
-				      GTK_MESSAGE_ERROR);
+	primary = g_strdup_printf (_("\"%s\" cannot be added to the selection."), name);
+	brasero_app_alert (brasero_app_get_default (),
+			   primary,
+			   _("It is a recursive symlink"),
+			   GTK_MESSAGE_ERROR);
 	g_free (primary);
 	g_free (name);
 }
@@ -956,11 +935,11 @@ brasero_data_disc_unknown_uri_cb (BraseroDataVFS *vfs,
 		return;
 	}
 
-	primary = g_strdup_printf (_("\"%s\" cannot be added to the selection:"), name);
-	brasero_utils_message_dialog (gtk_widget_get_toplevel (GTK_WIDGET (self)),
-				      primary,
-				      _("it doesn't exist at the specified location."),
-				      GTK_MESSAGE_ERROR);
+	primary = g_strdup_printf (_("\"%s\" cannot be added to the selection."), name);
+	brasero_app_alert (brasero_app_get_default (),
+			   primary,
+			   _("It does not exist at the specified location"),
+			   GTK_MESSAGE_ERROR);
 	g_free (primary);
 	g_free (name);
 }
@@ -971,8 +950,8 @@ brasero_data_disc_name_collision_cb (BraseroDataProject *project,
 				     BraseroDataDisc *self)
 {
 	gint answer;
+	gchar *string;
 	GtkWidget *dialog;
-	GtkWidget *toplevel;
 	BraseroDataDiscPrivate *priv;
 
 	priv = BRASERO_DATA_DISC_PRIVATE (self);
@@ -982,22 +961,20 @@ brasero_data_disc_name_collision_cb (BraseroDataProject *project,
 		return FALSE;
 	}
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
-	dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-					 GTK_DIALOG_DESTROY_WITH_PARENT |
-					 GTK_DIALOG_MODAL,
-					 GTK_MESSAGE_WARNING,
-					 GTK_BUTTONS_NONE,
-					 _("\"%s\" already exists in the directory:"),
-					 name);
-
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Already Existing File"));
+	string = g_strdup_printf (_("Do you really want to replace \"%s\"?"), name);
+	dialog = brasero_app_dialog (brasero_app_get_default (),
+				     string,
+				     GTK_BUTTONS_NONE,
+				     GTK_MESSAGE_WARNING);
+	g_free (string);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("do you really want to replace it?"));
+						  _("It already exists in the directory."));
 
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Don't replace"), GTK_RESPONSE_NO);
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Replace"), GTK_RESPONSE_YES);
+	/* Translators: Keep means we're keeping the files that already existed
+	 * Replace means we're replacing it with a new one with the same name */
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Keep Project File"), GTK_RESPONSE_NO);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Replace Project File"), GTK_RESPONSE_YES);
 
 	gtk_widget_show_all (dialog);
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -1012,8 +989,8 @@ brasero_data_disc_2G_file_cb (BraseroDataProject *project,
 			      BraseroDataDisc *self)
 {
 	gint answer;
+	gchar *string;
 	GtkWidget *dialog;
-	GtkWidget *toplevel;
 	BraseroDataDiscPrivate *priv;
 
 	priv = BRASERO_DATA_DISC_PRIVATE (self);
@@ -1027,24 +1004,20 @@ brasero_data_disc_2G_file_cb (BraseroDataProject *project,
 		return FALSE;
 	}
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
-	dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-					 GTK_DIALOG_DESTROY_WITH_PARENT |
-					 GTK_DIALOG_MODAL,
-					 GTK_MESSAGE_WARNING,
-					 GTK_BUTTONS_NONE,
-					 _("Do you really want to add \"%s\" to the selection and use the third version of ISO9660 standard to support it?"),
-					 name);
-
-	gtk_window_set_title (GTK_WINDOW (dialog), _("File Over 2 GiB"));
+	string = g_strdup_printf (_("Do you really want to add \"%s\" to the selection and use the third version of ISO9660 standard to support it?"), name);
+	dialog = brasero_app_dialog (brasero_app_get_default (),
+				     string,
+				     GTK_BUTTONS_NONE,
+				     GTK_MESSAGE_WARNING);
+	g_free (string);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("The size of the file is over 2 GiB. This isn't supported by ISO9660 standard in his first and second versions (the most widespread ones)."
+						  _("The size of the file is over 2 GiB. Files larger than 2 GiB are not supported by ISO9660 standard in its first and second versions (the most widespread ones)."
 						    "\nIt is recommended to use the third version of ISO9660 standard which is supported by most of the operating systems including Linux and all versions of Windows ©."
-						    "\nA known exception is MacOS X that can't read images created with version 3 of ISO9660 standard."));
+						    "\nHowever MacOS X cannot read images created with version 3 of ISO9660 standard."));
 
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Don't add"), GTK_RESPONSE_NO);
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Add"), GTK_RESPONSE_YES);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_NO);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Add File"), GTK_RESPONSE_YES);
 
 	gtk_widget_show_all (dialog);
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -1060,8 +1033,8 @@ brasero_data_disc_deep_directory_cb (BraseroDataProject *project,
 				     BraseroDataDisc *self)
 {
 	gint answer;
+	gchar *string;
 	GtkWidget *dialog;
-	GtkWidget *toplevel;
 	BraseroDataDiscPrivate *priv;
 
 	priv = BRASERO_DATA_DISC_PRIVATE (self);
@@ -1075,24 +1048,20 @@ brasero_data_disc_deep_directory_cb (BraseroDataProject *project,
 		return FALSE;
 	}
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
-	dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-					 GTK_DIALOG_DESTROY_WITH_PARENT |
-					 GTK_DIALOG_MODAL,
-					 GTK_MESSAGE_WARNING,
-					 GTK_BUTTONS_NONE,
-					 _("Do you really want to add \"%s\" to the selection?"),
-					 name);
-
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Deep Directory"));
+	string = g_strdup_printf (_("Do you really want to add \"%s\" to the selection?"), name);
+	dialog = brasero_app_dialog (brasero_app_get_default (),
+				     string,
+				     GTK_BUTTONS_NONE,
+				     GTK_MESSAGE_WARNING);
+	g_free (string);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 						  _("The children of this directory will have 6 parent directories. This is a violation of the ISO9660 standard which only allows 6."
-						    "\nBrasero can create an image of such a file hierarchy and burn it; but the media may not be readable on all operating systems."
-						    "\nNOTE: such a file hierarchy is known to work on linux."));
+						    "\nBrasero can create an image of such a file hierarchy and burn it; but the disc may not be readable on all operating systems."
+						    "\nNOTE: Such a file hierarchy is known to work on linux."));
 
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Don't add"), GTK_RESPONSE_NO);
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Add"), GTK_RESPONSE_YES);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_NO);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Add File"), GTK_RESPONSE_YES);
 
 	gtk_widget_show_all (dialog);
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -1102,14 +1071,35 @@ brasero_data_disc_deep_directory_cb (BraseroDataProject *project,
 	return (answer != GTK_RESPONSE_YES);
 }
 
+static gboolean
+brasero_data_disc_size_changed (gpointer user_data)
+{
+	gint64 size;
+	BraseroDataDisc *self;
+	BraseroDataDiscPrivate *priv;
+
+	self = BRASERO_DATA_DISC (user_data);
+	priv = BRASERO_DATA_DISC_PRIVATE (self);
+
+	size = brasero_data_project_get_size (BRASERO_DATA_PROJECT (priv->project));
+	brasero_disc_size_changed (BRASERO_DISC (self), size);
+
+	priv->size_changed_id = 0;
+	return FALSE;
+}
+
 static void
 brasero_data_disc_size_changed_cb (BraseroDataProject *project,
 				   BraseroDataDisc *self)
 {
-	gint64 size;
+	BraseroDataDiscPrivate *priv;
 
-	size = brasero_data_project_get_size (project);
-	brasero_disc_size_changed (BRASERO_DISC (self), size);
+	priv = BRASERO_DATA_DISC_PRIVATE (self);
+
+	if (!priv->size_changed_id)
+		priv->size_changed_id = g_timeout_add (500,
+						       brasero_data_disc_size_changed,
+						       self);
 }
 
 static void
@@ -1163,14 +1153,15 @@ brasero_data_disc_import_button_new (BraseroDataDisc *self,
 
 	tooltip = brasero_medium_get_tooltip (medium);
 	/* Translators: %s is a string describing the type of medium and the 
-	 * drive it is in. */
+	 * drive it is in. It's a tooltip. */
 	string = g_strdup_printf (_("Import %s"), tooltip);
 	g_free (tooltip);
 	tooltip = string;
 
 	volume_name = brasero_volume_get_name (BRASERO_VOLUME (medium));
-	/* Translators: %s is the name of the volume to import */
-	string = g_strdup_printf (_("Import %s"), volume_name);
+	/* Translators: %s is the name of the volume to import. It's a menu
+	 * entry and toolbar button (text added later). */
+	string = g_strdup_printf (_("I_mport %s"), volume_name);
 	g_free (volume_name);
 	volume_name = string;
 
@@ -1198,9 +1189,9 @@ brasero_data_disc_import_button_new (BraseroDataDisc *self,
 			   BRASERO_DATA_DISC_MEDIUM,
 			   medium);
 
-	/* Translators: This is a verb */
 	g_object_set (action,
-		      "short-label", _("Import"), /* for toolbar buttons */
+			/* Translators: This is a verb. It's a toolbar button. */
+		      "short-label", _("I_mport"),
 		      NULL);
 
 	description = g_strdup_printf ("<ui>"
@@ -1270,7 +1261,7 @@ brasero_data_disc_session_available_cb (BraseroDataSession *session,
 
 		brasero_notify_button_add (BRASERO_NOTIFY (priv->message),
 					   BRASERO_DISC_MESSAGE (message),
-					   _("_Import Session"),
+					   _("I_mport Session"),
 					   _("Click here to import its contents"),
 					   GTK_RESPONSE_OK);
 
@@ -1346,6 +1337,11 @@ brasero_data_disc_clear (BraseroDisc *disc)
 	if (priv->loading)
 		return;
 
+	if (priv->size_changed_id) {
+		g_source_remove (priv->size_changed_id);
+		priv->size_changed_id = 0;
+	}
+
 	if (brasero_data_session_get_loaded_medium (BRASERO_DATA_SESSION (priv->project)))
 		brasero_data_session_remove_last (BRASERO_DATA_SESSION (priv->project));
 
@@ -1377,6 +1373,11 @@ brasero_data_disc_reset (BraseroDisc *disc)
 
 	priv = BRASERO_DATA_DISC_PRIVATE (disc);
 
+	if (priv->size_changed_id) {
+		g_source_remove (priv->size_changed_id);
+		priv->size_changed_id = 0;
+	}
+
 	/* Unload session */
 	if (brasero_data_session_get_loaded_medium (BRASERO_DATA_SESSION (priv->project)))
 		brasero_data_session_remove_last (BRASERO_DATA_SESSION (priv->project));
@@ -1707,7 +1708,9 @@ brasero_data_disc_load_track (BraseroDisc *disc,
 }
 
 static BraseroDiscResult
-brasero_data_disc_get_status (BraseroDisc *disc)
+brasero_data_disc_get_status (BraseroDisc *disc,
+			      gint *remaining,
+			      gchar **current_task)
 {
 	BraseroDataDiscPrivate *priv;
 
@@ -1718,8 +1721,15 @@ brasero_data_disc_get_status (BraseroDisc *disc)
 
 	/* This one goes before the next since a node may be loading but not
 	 * yet in the project and therefore project will look empty */
-	if (brasero_data_vfs_is_active (BRASERO_DATA_VFS (priv->project)))
+	if (brasero_data_vfs_is_active (BRASERO_DATA_VFS (priv->project))) {
+		if (remaining)
+			*remaining = -1;
+
+		if (current_task)
+			*current_task = g_strdup (_("Analysing files"));
+
 		return BRASERO_DISC_NOT_READY;
+	}
 
 	if (brasero_data_project_is_empty (priv->project))
 		return BRASERO_DISC_ERROR_EMPTY_SELECTION;
@@ -1787,7 +1797,7 @@ brasero_data_disc_add_ui (BraseroDisc *disc,
 
 		action = gtk_action_group_get_action (priv->disc_group, "NewFolder");
 		g_object_set (action,
-			      "short-label", _("New Folder"), /* for toolbar buttons */
+			      "short-label", _("New _Folder"), /* for toolbar buttons */
 			      NULL);
 	
 		priv->manager = manager;
@@ -1946,7 +1956,7 @@ brasero_data_disc_rename_activated (BraseroDataDisc *disc)
 		dialog = gtk_dialog_new_with_buttons (_("File Renaming"),
 						      GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (disc))),
 						      GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT,
-						      _("_Don't rename"), GTK_RESPONSE_CANCEL,
+						      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 						      _("_Rename"), GTK_RESPONSE_APPLY,
 						      NULL);
 		gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
@@ -2529,7 +2539,6 @@ brasero_data_disc_init (BraseroDataDisc *object)
 						nb_targets_source,
 						GDK_ACTION_MOVE);
 
-	/* FIXME: ..... */
 	g_signal_connect (G_OBJECT (priv->tree),
 			  "row-expanded",
 			  G_CALLBACK (brasero_data_disc_row_expanded_cb),
@@ -2565,6 +2574,11 @@ brasero_data_disc_finalize (GObject *object)
 
 	priv = BRASERO_DATA_DISC_PRIVATE (object);
 
+	if (priv->size_changed_id) {
+		g_source_remove (priv->size_changed_id);
+		priv->size_changed_id = 0;
+	}
+
 	if (priv->message) {
 		g_object_unref (priv->message);
 		priv->message = NULL;
