@@ -60,11 +60,13 @@ struct _BraseroDiscOptionDialogPrivate {
 	GtkWidget *joliet_toggle;
 
 	GtkWidget *video_options;
-	GtkWidget *dvd_audio;
 	GtkWidget *vcd_label;
 	GtkWidget *vcd_button;
 	GtkWidget *svcd_button;
 
+	GtkWidget *button_4_3;
+	GtkWidget *button_16_9;
+
 	gulong valid_sig;
 
 	guint joliet_warning:1;
@@ -76,6 +78,43 @@ typedef struct _BraseroDiscOptionDialogPrivate BraseroDiscOptionDialogPrivate;
 
 static GtkDialogClass *parent_class = NULL;
 
+
+static void
+brasero_disc_option_audio_AC3 (BraseroDiscOptionDialog *dialog)
+{
+	BraseroBurnSession *session;
+	GValue *value = NULL;
+
+	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
+
+	value = g_new0 (GValue, 1);
+	g_value_init (value, G_TYPE_INT);
+	g_value_set_int (value, BRASERO_AUDIO_FORMAT_AC3);
+	brasero_burn_session_tag_add (session,
+				      BRASERO_DVD_AUDIO_STREAMS,
+				      value);
+
+	g_object_unref (session);
+}
+
+static void
+brasero_disc_option_audio_MP2 (BraseroDiscOptionDialog *dialog)
+{
+	BraseroBurnSession *session;
+	GValue *value = NULL;
+
+	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
+
+	value = g_new0 (GValue, 1);
+	g_value_init (value, G_TYPE_INT);
+	g_value_set_int (value, BRASERO_AUDIO_FORMAT_MP2);
+	brasero_burn_session_tag_add (session,
+				      BRASERO_DVD_AUDIO_STREAMS,
+				      value);
+
+	g_object_unref (session);
+}
+
 /**
  * These functions are used when caps-changed event or drive-changed event
  * are generated. They are used to check that flags or fs are valid.
@@ -151,25 +190,41 @@ brasero_disc_option_dialog_update_video (BraseroDiscOptionDialog *dialog)
 
 	priv = BRASERO_DISC_OPTION_DIALOG_PRIVATE (dialog);
 
+	/* means we haven't initialized yet */
+	if (!priv->vcd_label)
+		return;
+
 	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
 	media = brasero_burn_session_get_dest_media (session);
 
 	if (media & BRASERO_MEDIUM_DVD) {
-		gtk_widget_show (priv->dvd_audio);
+		brasero_disc_option_audio_AC3 (dialog);
 		gtk_widget_hide (priv->vcd_label);
 		gtk_widget_hide (priv->vcd_button);
 		gtk_widget_hide (priv->svcd_button);
+
+		gtk_widget_set_sensitive (priv->button_4_3, TRUE);
+		gtk_widget_set_sensitive (priv->button_16_9, TRUE);
 	}
 	else if (media & BRASERO_MEDIUM_CD) {
-		gtk_widget_hide (priv->dvd_audio);
+		brasero_disc_option_audio_MP2 (dialog);
 		gtk_widget_show (priv->vcd_label);
 		gtk_widget_show (priv->vcd_button);
 		gtk_widget_show (priv->svcd_button);
+
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->vcd_button))) {
+			gtk_widget_set_sensitive (priv->button_4_3, FALSE);
+			gtk_widget_set_sensitive (priv->button_16_9, FALSE);
+		}
+		else {
+			gtk_widget_set_sensitive (priv->button_4_3, TRUE);
+			gtk_widget_set_sensitive (priv->button_16_9, TRUE);
+		}
 	}
 	else if (media & BRASERO_MEDIUM_FILE) {
 		BraseroImageFormat format;
 
-		/* if we create a CUE file then that's a SVCD */
+		/* if we create a CUE file then that's a (S)VCD */
 		format = brasero_burn_session_get_output_format (session);
 		if (format == BRASERO_IMAGE_FORMAT_NONE) {
 			g_object_unref (session);
@@ -177,16 +232,28 @@ brasero_disc_option_dialog_update_video (BraseroDiscOptionDialog *dialog)
 		}
 
 		if (format == BRASERO_IMAGE_FORMAT_CUE) {
-			gtk_widget_hide (priv->dvd_audio);
+			brasero_disc_option_audio_MP2 (dialog);
 			gtk_widget_show (priv->vcd_label);
 			gtk_widget_show (priv->vcd_button);
 			gtk_widget_show (priv->svcd_button);
+
+			if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->vcd_button))) {
+				gtk_widget_set_sensitive (priv->button_4_3, FALSE);
+				gtk_widget_set_sensitive (priv->button_16_9, FALSE);
+			}
+			else {
+				gtk_widget_set_sensitive (priv->button_4_3, TRUE);
+				gtk_widget_set_sensitive (priv->button_16_9, TRUE);
+			}
 		}
 		else if (format == BRASERO_IMAGE_FORMAT_BIN) {
-			gtk_widget_show (priv->dvd_audio);
+			brasero_disc_option_audio_AC3 (dialog);
 			gtk_widget_hide (priv->vcd_label);
 			gtk_widget_hide (priv->vcd_button);
 			gtk_widget_hide (priv->svcd_button);
+
+			gtk_widget_set_sensitive (priv->button_4_3, TRUE);
+			gtk_widget_set_sensitive (priv->button_16_9, TRUE);
 		}
 	}
 
@@ -342,74 +409,6 @@ brasero_disc_option_dialog_add_data_options (BraseroDiscOptionDialog *dialog)
 	gtk_widget_show_all (widget);
 }
 
-static void
-brasero_disc_option_dialog_AC3 (GtkToggleButton *button,
-				BraseroDiscOptionDialog *dialog)
-{
-	BraseroBurnSession *session;
-	BraseroAudioFormat format;
-	GValue *value = NULL;
-
-	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
-
-	brasero_burn_session_tag_lookup (session,
-					 BRASERO_DVD_AUDIO_STREAMS,
-					 &value);
-
-	if (value)
-		format = g_value_get_int (value);
-	else
-		format = BRASERO_AUDIO_FORMAT_NONE;
-
-	if (gtk_toggle_button_get_active (button))
-		format |= BRASERO_AUDIO_FORMAT_AC3;
-	else
-		format &= ~BRASERO_AUDIO_FORMAT_AC3;
-
-	value = g_new0 (GValue, 1);
-	g_value_init (value, G_TYPE_INT);
-	g_value_set_int (value, format);
-	brasero_burn_session_tag_add (session,
-				      BRASERO_DVD_AUDIO_STREAMS,
-				      value);
-
-	g_object_unref (session);
-}
-
-static void
-brasero_disc_option_dialog_MP2 (GtkToggleButton *button,
-				BraseroDiscOptionDialog *dialog)
-{
-	BraseroBurnSession *session;
-	BraseroAudioFormat format;
-	GValue *value = NULL;
-
-	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
-
-	brasero_burn_session_tag_lookup (session,
-					 BRASERO_DVD_AUDIO_STREAMS,
-					 &value);
-
-	if (value)
-		format = g_value_get_int (value);
-	else
-		format = BRASERO_AUDIO_FORMAT_NONE;
-
-	if (gtk_toggle_button_get_active (button))
-		format |= BRASERO_AUDIO_FORMAT_MP2;
-	else
-		format &= ~BRASERO_AUDIO_FORMAT_MP2;
-
-	value = g_new0 (GValue, 1);
-	g_value_init (value, G_TYPE_INT);
-	g_value_set_int (value, format);
-	brasero_burn_session_tag_add (session,
-				      BRASERO_DVD_AUDIO_STREAMS,
-				      value);
-
-	g_object_unref (session);
-}
-
 static void
 brasero_disc_option_dialog_set_tag (BraseroDiscOptionDialog *dialog,
 				    const gchar *tag,
@@ -434,24 +433,39 @@ static void
 brasero_disc_option_dialog_SVCD (GtkToggleButton *button,
 				 BraseroDiscOptionDialog *dialog)
 {
+	BraseroDiscOptionDialogPrivate *priv;
+
 	if (!gtk_toggle_button_get_active (button))
 		return;
 
 	brasero_disc_option_dialog_set_tag (dialog,
 					    BRASERO_VCD_TYPE,
 					    BRASERO_SVCD);
+
+	priv = BRASERO_DISC_OPTION_DIALOG_PRIVATE (dialog);
+
+	gtk_widget_set_sensitive (priv->button_4_3, TRUE);
+	gtk_widget_set_sensitive (priv->button_16_9, TRUE);
 }
 
 static void
 brasero_disc_option_dialog_VCD (GtkToggleButton *button,
 				BraseroDiscOptionDialog *dialog)
 {
+	BraseroDiscOptionDialogPrivate *priv;
+
 	if (!gtk_toggle_button_get_active (button))
 		return;
 
 	brasero_disc_option_dialog_set_tag (dialog,
 					    BRASERO_VCD_TYPE,
 					    BRASERO_VCD_V2);
+
+	priv = BRASERO_DISC_OPTION_DIALOG_PRIVATE (dialog);
+	gtk_widget_set_sensitive (priv->button_4_3, FALSE);
+	gtk_widget_set_sensitive (priv->button_16_9, FALSE);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->button_4_3), TRUE);
 }
 
 static void
@@ -516,20 +530,6 @@ brasero_disc_option_dialog_4_3 (GtkToggleButton *button,
 					    BRASERO_VIDEO_ASPECT_4_3);
 }
 
-static void
-brasero_disc_option_dialog_native_aspect (GtkToggleButton *button,
-					  BraseroDiscOptionDialog *dialog)
-{
-	BraseroBurnSession *session;
-
-	if (!gtk_toggle_button_get_active (button))
-		return;
-
-	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
-	brasero_burn_session_tag_remove (session, BRASERO_VIDEO_OUTPUT_ASPECT);
-	g_object_unref (session);
-}
-
 static void
 brasero_disc_option_dialog_add_video_options (BraseroDiscOptionDialog *dialog)
 {
@@ -628,11 +628,12 @@ brasero_disc_option_dialog_add_video_options (BraseroDiscOptionDialog *dialog)
 			  dialog);
 	gtk_table_attach (GTK_TABLE (table),
 			  button1,
-			  3, 4,
+			  1, 2,
 			  1, 2,
 			  GTK_FILL,
 			  GTK_FILL,
 			  0, 0);
+	priv->button_4_3 = button1;
 
 	button2 = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON (button1),
 								  _("_16:9"));
@@ -647,21 +648,7 @@ brasero_disc_option_dialog_add_video_options (BraseroDiscOptionDialog *dialog)
 			  GTK_FILL,
 			  GTK_FILL,
 			  0, 0);
-
-	button3 = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON (button1),
-								  _("Native aspect _ratio"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button3), TRUE);
-	g_signal_connect (button3,
-			  "toggled",
-			  G_CALLBACK (brasero_disc_option_dialog_native_aspect),
-			  dialog);
-	gtk_table_attach (GTK_TABLE (table),
-			  button3,
-			  1, 2,
-			  1, 2,
-			  GTK_FILL,
-			  GTK_FILL,
-			  0, 0);
+	priv->button_16_9 = button2;
 
 	/* Video options for (S)VCD */
 	label = gtk_label_new (_("VCD type:"));
@@ -715,33 +702,22 @@ brasero_disc_option_dialog_add_video_options (BraseroDiscOptionDialog *dialog)
 
 	gtk_box_pack_start (GTK_BOX (widget), options, FALSE, FALSE, 0);
 
-	/* Audio options for DVDs */
-	button1 = gtk_check_button_new_with_mnemonic (_("Add _AC3 audio stream"));
-	button2 = gtk_check_button_new_with_mnemonic (_("Add _MP2 audio stream"));
-
-	string = g_strdup_printf ("<b>%s</b>", _("Audio Options"));
-	options = brasero_utils_pack_properties (string,
-						 button1,
-						 button2,
-						 NULL);
-	g_free (string);
-
-	g_signal_connect (button1,
-			  "clicked",
-			  G_CALLBACK (brasero_disc_option_dialog_AC3),
-			  dialog);
-	g_signal_connect (button2,
-			  "clicked",
-			  G_CALLBACK (brasero_disc_option_dialog_MP2),
-			  dialog);
-
-	gtk_box_pack_start (GTK_BOX (widget), options, FALSE, FALSE, 0);
-	priv->dvd_audio = options;
+	/* NOTE: audio options for DVDs were removed. For SVCD that is MP2 and
+	 * for Video DVD even if we have a choice AC3 is the most widespread
+	 * audio format. So use AC3 by default. */
 
 	gtk_widget_show_all (widget);
 	brasero_disc_option_dialog_update_video (dialog);
 
 	priv->video_options = widget;
+
+	/* Just to make sure our tags are correct in BraseroBurnSession */
+	brasero_disc_option_dialog_set_tag (dialog,
+					    BRASERO_VCD_TYPE,
+					    BRASERO_SVCD);
+	brasero_disc_option_dialog_set_tag (dialog,
+					    BRASERO_VIDEO_OUTPUT_ASPECT,
+					    BRASERO_VIDEO_ASPECT_4_3);
 }
 
 void
@@ -818,9 +794,8 @@ brasero_disc_option_dialog_valid_media_cb (BraseroSessionCfg *session,
 	/* update the joliet button */
 	brasero_disc_option_dialog_update_joliet (self);
 
-	/* for video disc see what's the output : CD or DVD */
-	if (priv->dvd_audio)
-		brasero_disc_option_dialog_update_video (self);
+	/* for video disc see what's the output: CD or DVD */
+	brasero_disc_option_dialog_update_video (self);
 }
 
 static void
