@@ -34,16 +34,7 @@
 #include <glib-object.h>
 #include <glib/gi18n-lib.h>
 
-#include <gtk/gtkstock.h>
-#include <gtk/gtkaction.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkfilefilter.h>
-#include <gtk/gtkfilechooser.h>
-#include <gtk/gtkfilechooserwidget.h>
-#include <gtk/gtkfilechooserdialog.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtk.h>
 
 #include "brasero-app.h"
 #include "brasero-utils.h"
@@ -52,10 +43,7 @@
 #include "brasero-project-manager.h"
 #include "brasero-file-chooser.h"
 #include "brasero-uri-container.h"
-#include "brasero-image-option-dialog.h"
-#include "brasero-burn-dialog.h"
 #include "brasero-project-type-chooser.h"
-#include "brasero-disc-copy-dialog.h"
 #include "brasero-io.h"
 #include "burn-caps.h"
 #include "burn-medium-monitor.h"
@@ -118,15 +106,15 @@ static GtkActionEntry entries [] = {
 	{"NewChoose", GTK_STOCK_NEW, N_("_Empty Project"), NULL,
 	 N_("Let you choose your new project"), G_CALLBACK (brasero_project_manager_new_empty_prj_cb)},
 	{"NewAudio", "media-optical-audio-new", N_("New _Audio Project"), NULL,
-	 N_("Create a new audio project"), G_CALLBACK (brasero_project_manager_new_audio_prj_cb)},
+	 N_("Create a traditional audio CD that will be playable on computers and stereos"), G_CALLBACK (brasero_project_manager_new_audio_prj_cb)},
 	{"NewData", "media-optical-data-new", N_("New _Data Project"), NULL,
-	 N_("Create a new data project"), G_CALLBACK (brasero_project_manager_new_data_prj_cb)},
+	 N_("Create a CD/DVD containing any type of data that can only be read on a computer"), G_CALLBACK (brasero_project_manager_new_data_prj_cb)},
 	{"NewVideo", "media-optical-video-new", N_("New _Video Project"), NULL,
-	 N_("Create a new video project"), G_CALLBACK (brasero_project_manager_new_video_prj_cb)},
+	 N_("Create a video DVD or a SVCD that are readable on TV readers"), G_CALLBACK (brasero_project_manager_new_video_prj_cb)},
 	{"NewCopy", "media-optical-copy", N_("Copy _Disc..."), NULL,
-	 N_("Copy a disc"), G_CALLBACK (brasero_project_manager_new_copy_prj_cb)},
+	 N_("Create a 1:1 copy of an audio CD or a data CD/DVD on your hardisk or on another CD/DVD"), G_CALLBACK (brasero_project_manager_new_copy_prj_cb)},
 	{"NewIso", "iso-image-burn", N_("_Burn Image..."), NULL,
-	 N_("Burn an image"), G_CALLBACK (brasero_project_manager_new_iso_prj_cb)},
+	 N_("Burn an existing CD/DVD image to disc"), G_CALLBACK (brasero_project_manager_new_iso_prj_cb)},
 
 	{"Open", GTK_STOCK_OPEN, N_("_Open..."), NULL,
 	 N_("Open a project"), G_CALLBACK (brasero_project_manager_open_cb)},
@@ -182,6 +170,8 @@ struct BraseroProjectManagerPrivate {
 	guint status_ctx;
 
 	GtkActionGroup *action_group;
+
+	guint oneshot:1;
 };
 
 #define BRASERO_PROJECT_MANAGER_CONNECT_CHANGED(manager, container)		\
@@ -241,12 +231,10 @@ brasero_project_manager_set_statusbar (BraseroProjectManager *manager,
 				       gint files_num)
 {
 	gchar *status_string = NULL;
-	GtkWidget *toplevel;
 	GtkWidget *status;
 	gint valid_num;
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-	status = brasero_app_get_statusbar1 (BRASERO_APP (toplevel));
+	status = brasero_app_get_statusbar1 (brasero_app_get_default ());
 
 	if (!manager->priv->status_ctx)
 		manager->priv->status_ctx = gtk_statusbar_get_context_id (GTK_STATUSBAR (status),
@@ -368,9 +356,12 @@ brasero_project_manager_selected_uris_preview (gpointer data)
 	for (iter = manager->priv->selected; iter && *iter; iter ++)
 		list = g_slist_prepend (list, *iter);
 
-	flags = BRASERO_IO_INFO_RECURSIVE|BRASERO_IO_INFO_IDLE;
-	if (manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO)
+	flags = BRASERO_IO_INFO_IDLE;
+	if (manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO
+	||  manager->priv->type == BRASERO_PROJECT_TYPE_VIDEO)
 		flags |= BRASERO_IO_INFO_METADATA;
+	else if (manager->priv->type == BRASERO_PROJECT_TYPE_DATA)
+		flags |= BRASERO_IO_INFO_RECURSIVE;
 
 	brasero_io_get_file_count (manager->priv->io,
 				   list,
@@ -448,11 +439,9 @@ brasero_project_manager_selected_uris_changed (BraseroURIContainer *container,
 
 	manager->priv->selected = uris;
 	if (!manager->priv->selected) {
-		GtkWidget *toplevel;
  		GtkWidget *status;
  
- 		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
- 		status = brasero_app_get_statusbar1 (BRASERO_APP (toplevel));
+ 		status = brasero_app_get_statusbar1 (brasero_app_get_default ());
  
  		if (!manager->priv->status_ctx)
  			manager->priv->status_ctx = gtk_statusbar_get_context_id (GTK_STATUSBAR (status),
@@ -476,7 +465,6 @@ brasero_project_manager_sidepane_changed (BraseroLayout *layout,
 					  BraseroProjectManager *manager)
 {
 	if (!visible) {
-		GtkWidget *toplevel;
  		GtkWidget *status;
  
 		/* If sidepane is disabled, remove any text about selection */
@@ -484,8 +472,7 @@ brasero_project_manager_sidepane_changed (BraseroLayout *layout,
 			brasero_io_cancel_by_base (manager->priv->io,
 						   manager->priv->size_preview);
 
- 		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
- 		status = brasero_app_get_statusbar1 (BRASERO_APP (toplevel));
+ 		status = brasero_app_get_statusbar1 (brasero_app_get_default ());
 
  		gtk_statusbar_pop (GTK_STATUSBAR (status), manager->priv->status_ctx);
 
@@ -517,121 +504,6 @@ brasero_project_manager_register_ui (BraseroProjectManager *manager,
    	brasero_layout_register_ui (BRASERO_LAYOUT (manager->priv->layout), ui_manager);
 }
 
-static void
-brasero_project_manager_burn (BraseroProjectManager *manager,
-			      BraseroBurnSession *session)
-{
-	GtkWidget *toplevel;
-	GtkWidget *dialog;
-	gboolean destroy;
-
-	/* now setup the burn dialog */
-	dialog = brasero_burn_dialog_new ();
-
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
-	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-
-	gtk_widget_hide (toplevel);
-	gtk_widget_show (dialog);
-
-	brasero_burn_dialog_run (BRASERO_BURN_DIALOG (dialog),
-				 session,
-				 &destroy);
-
-	gtk_widget_destroy (dialog);
-
-	if (!destroy) {
-		brasero_project_manager_switch (manager,
-						BRASERO_PROJECT_TYPE_INVALID,
-						NULL,
-						NULL,
-						TRUE);
-		gtk_widget_show (toplevel);
-	}
-	else
-		gtk_widget_destroy (toplevel);
-}
-
-static void
-brasero_project_manager_burn_iso_dialog (BraseroProjectManager *manager,
-					 const gchar *uri)
-{
-	BraseroBurnSession *session;
-	GtkResponseType result;
-	GtkWidget *toplevel;
-	GtkWidget *dialog;
-
-	/* setup, show, and run options dialog */
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-
-	dialog = brasero_image_option_dialog_new ();
-	brasero_image_option_dialog_set_image_uri (BRASERO_IMAGE_OPTION_DIALOG (dialog), uri);
-
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
-	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
-	gtk_widget_show (dialog);
-
-	result = gtk_dialog_run (GTK_DIALOG (dialog));
-	if (result != GTK_RESPONSE_OK) {
-		gtk_widget_destroy (dialog);
-		return;
-	}
-
-	session = brasero_image_option_dialog_get_session (BRASERO_IMAGE_OPTION_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
-
-	if (!session)
-		return;
-
-	brasero_project_manager_burn (manager, session);
-	g_object_unref (session);
-}
-
-static void
-brasero_project_manager_copy_disc (BraseroProjectManager *manager,
-				   const gchar *device)
-{
-	BraseroBurnSession *session;
-	GtkResponseType result;
-	GtkWidget *toplevel;
-	GtkWidget *dialog;
-
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-
-	dialog = brasero_disc_copy_dialog_new ();
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
-	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
-	gtk_widget_show (dialog);
-
-	/* if a device is specified then get the corresponding medium */
-	if (device) {
-		BraseroDrive *drive;
-		BraseroMediumMonitor *monitor;
-
-		monitor = brasero_medium_monitor_get_default ();
-		drive = brasero_medium_monitor_get_drive (monitor, device);
-		g_object_unref (monitor);
-
-		brasero_disc_copy_dialog_set_drive (BRASERO_DISC_COPY_DIALOG (dialog), drive);
-		g_object_unref (drive);
-	}
-
-	result = gtk_dialog_run (GTK_DIALOG (dialog));
-	if (result != GTK_RESPONSE_OK) {
-		gtk_widget_destroy (dialog);
-		return;
-	}
-
-	session = brasero_disc_copy_dialog_get_session (BRASERO_DISC_COPY_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
-
-	brasero_project_manager_burn (manager, session);
-	g_object_unref (session);
-}
-
 static void
 brasero_project_manager_switch (BraseroProjectManager *manager,
 				BraseroProjectType type,
@@ -642,18 +514,25 @@ brasero_project_manager_switch (BraseroProjectManager *manager,
 	GtkWidget *toplevel;
 	GtkAction *action;
 
-	if ((manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO
-	||   manager->priv->type == BRASERO_PROJECT_TYPE_DATA
-	||   manager->priv->type == BRASERO_PROJECT_TYPE_VIDEO)
-	&&  !brasero_project_confirm_switch (BRASERO_PROJECT (manager->priv->project)))
-		return;
-
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
 
+	if (manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO
+	||  manager->priv->type == BRASERO_PROJECT_TYPE_DATA
+	||  manager->priv->type == BRASERO_PROJECT_TYPE_VIDEO) {
+		if (!brasero_project_confirm_switch (BRASERO_PROJECT (manager->priv->project)))
+			return;
+
+		if (manager->priv->oneshot) {
+			/* Here we may have to close brasero altogether */
+			gtk_widget_destroy (toplevel);
+			return;
+		}
+	}
+
 	if (manager->priv->status_ctx) {
 		GtkWidget *status;
 
-		status = brasero_app_get_statusbar1 (BRASERO_APP (toplevel));
+		status = brasero_app_get_statusbar1 (brasero_app_get_default ());
 		gtk_statusbar_pop (GTK_STATUSBAR (status), manager->priv->status_ctx);
 	}
 
@@ -711,7 +590,7 @@ brasero_project_manager_switch (BraseroProjectManager *manager,
 		}
 
 		if (toplevel)
-			gtk_window_set_title (GTK_WINDOW (toplevel), _("Brasero - New Video disc project"));
+			gtk_window_set_title (GTK_WINDOW (toplevel), _("Brasero - New Video Disc Project"));
 	}
 	else if (type == BRASERO_PROJECT_TYPE_ISO) {
 		brasero_layout_load (BRASERO_LAYOUT (manager->priv->layout), BRASERO_LAYOUT_NONE);
@@ -722,7 +601,13 @@ brasero_project_manager_switch (BraseroProjectManager *manager,
 
 		if (toplevel)
 			gtk_window_set_title (GTK_WINDOW (toplevel), _("Brasero - New Image File"));
-		brasero_project_manager_burn_iso_dialog (manager, uri);
+
+		brasero_app_burn_image (brasero_app_get_default (), uri);
+		brasero_project_manager_switch (manager,
+						BRASERO_PROJECT_TYPE_INVALID,
+						NULL,
+						NULL,
+						TRUE);
 	}
 	else if (type == BRASERO_PROJECT_TYPE_COPY) {
 		brasero_layout_load (BRASERO_LAYOUT (manager->priv->layout), BRASERO_LAYOUT_NONE);
@@ -734,7 +619,12 @@ brasero_project_manager_switch (BraseroProjectManager *manager,
 		if (toplevel)
 			gtk_window_set_title (GTK_WINDOW (toplevel), _("Brasero - Disc Copy"));
 
-		brasero_project_manager_copy_disc (manager, uri);
+		brasero_app_copy_disc (brasero_app_get_default (), uri, NULL);
+		brasero_project_manager_switch (manager,
+						BRASERO_PROJECT_TYPE_INVALID,
+						NULL,
+						NULL,
+						TRUE);
 	}
 }
 
@@ -743,47 +633,55 @@ brasero_project_manager_type_changed_cb (BraseroProjectTypeChooser *chooser,
 					 BraseroProjectType type,
 					 BraseroProjectManager *manager)
 {
+	manager->priv->oneshot = FALSE;
 	brasero_project_manager_switch (manager, type, NULL, NULL, TRUE);
 }
 
 static void
 brasero_project_manager_new_empty_prj_cb (GtkAction *action, BraseroProjectManager *manager)
 {
+	manager->priv->oneshot = FALSE;
 	brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_INVALID, NULL, NULL, TRUE);
 }
 
 static void
 brasero_project_manager_new_audio_prj_cb (GtkAction *action, BraseroProjectManager *manager)
 {
+	manager->priv->oneshot = FALSE;
 	brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_AUDIO, NULL, NULL, TRUE);
 }
 
 static void
 brasero_project_manager_new_data_prj_cb (GtkAction *action, BraseroProjectManager *manager)
 {
+	manager->priv->oneshot = FALSE;
 	brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_DATA, NULL, NULL, TRUE);
 }
 
 static void
 brasero_project_manager_new_video_prj_cb (GtkAction *action, BraseroProjectManager *manager)
 {
+	manager->priv->oneshot = FALSE;
 	brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_VIDEO, NULL, NULL, TRUE);
 }
 
 static void
 brasero_project_manager_new_copy_prj_cb (GtkAction *action, BraseroProjectManager *manager)
 {
+	manager->priv->oneshot = FALSE;
 	brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_COPY, NULL, NULL, TRUE);
 }
 
 static void
 brasero_project_manager_new_iso_prj_cb (GtkAction *action, BraseroProjectManager *manager)
 {
+	manager->priv->oneshot = FALSE;
 	brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_ISO, NULL, NULL, TRUE);
 }
 
 void
-brasero_project_manager_audio (BraseroProjectManager *manager, GSList *uris)
+brasero_project_manager_audio (BraseroProjectManager *manager,
+			       GSList *uris)
 {
 	brasero_project_manager_switch (manager,
 					BRASERO_PROJECT_TYPE_AUDIO,
@@ -793,17 +691,38 @@ brasero_project_manager_audio (BraseroProjectManager *manager, GSList *uris)
 }
 
 void
-brasero_project_manager_data (BraseroProjectManager *manager, GSList *uris)
+brasero_project_manager_data (BraseroProjectManager *manager,
+			      GSList *uris)
 {
-	brasero_project_manager_switch (manager,
-					BRASERO_PROJECT_TYPE_DATA,
-					uris,
-					NULL,
-					TRUE);
+	gchar *burn_URI = NULL;
+
+	/* always add the contents of burn:/// URI if list is empty */
+	if (!uris) {
+		burn_URI = g_strdup ("burn:///");
+		uris = g_slist_prepend (NULL, burn_URI);
+	}
+
+	if (manager->priv->oneshot) {
+		brasero_project_set_data (BRASERO_PROJECT (manager->priv->project),
+					  uris);
+		brasero_project_burn (BRASERO_PROJECT (manager->priv->project));
+	}
+	else
+		brasero_project_manager_switch (manager,
+						BRASERO_PROJECT_TYPE_DATA,
+						uris,
+						NULL,
+						TRUE);
+	
+	if (burn_URI) {
+		g_slist_free (uris);
+		g_free (burn_URI);
+	}
 }
 
 void
-brasero_project_manager_video (BraseroProjectManager *manager, GSList *uris)
+brasero_project_manager_video (BraseroProjectManager *manager,
+			       GSList *uris)
 {
 	brasero_project_manager_switch (manager,
 					BRASERO_PROJECT_TYPE_VIDEO,
@@ -814,15 +733,25 @@ brasero_project_manager_video (BraseroProjectManager *manager, GSList *uris)
 
 void
 brasero_project_manager_copy (BraseroProjectManager *manager,
-			      const gchar *device)
+			      const gchar *device,
+			      const gchar *cover)
 {
-	brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_COPY, NULL, device, TRUE);
+	brasero_project_manager_switch (manager,
+					BRASERO_PROJECT_TYPE_COPY,
+					NULL,
+					device,
+					TRUE);
 }
 
 void
-brasero_project_manager_iso (BraseroProjectManager *manager, const gchar *uri)
+brasero_project_manager_iso (BraseroProjectManager *manager,
+			     const gchar *uri)
 {
-	brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_ISO, NULL, uri, TRUE);
+	brasero_project_manager_switch (manager,
+					BRASERO_PROJECT_TYPE_ISO,
+					NULL,
+					uri,
+					TRUE);
 }
 
 BraseroProjectType
@@ -853,6 +782,21 @@ brasero_project_manager_open_project (BraseroProjectManager *manager,
 	return type;
 }
 
+void
+brasero_project_manager_burn_project (BraseroProjectManager *manager,
+				      const gchar *uri)
+{
+	BraseroProjectType type;
+
+	brasero_project_manager_set_oneshot (manager, TRUE);
+	type = brasero_project_open_project (BRASERO_PROJECT (manager->priv->project), uri);
+	if (type == BRASERO_PROJECT_TYPE_INVALID)
+		return;
+
+	manager->priv->type = type;
+	brasero_project_burn (BRASERO_PROJECT (manager->priv->project));
+}
+
 #ifdef BUILD_PLAYLIST
 
 BraseroProjectType
@@ -919,18 +863,62 @@ brasero_project_manager_open_uri (BraseroProjectManager *manager,
 	gchar *uri;
 	GFile *file;
 	GFileInfo *info;
-	GtkWidget *dialog;
-	GtkWidget *window;
 	BraseroProjectType type;
 
 	/* FIXME: make that asynchronous */
+	/* NOTE: don't follow symlink because we want to identify them */
 	file = g_file_new_for_commandline_arg (uri_arg);
 	info = g_file_query_info (file,
-				  G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
-				  G_FILE_QUERY_INFO_NONE,
+				  G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE ","
+				  G_FILE_ATTRIBUTE_STANDARD_IS_SYMLINK ","
+				  G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET,
+				  G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
 				  NULL,
 				  NULL);
 
+	/* if that's a symlink, redo it on its target to get the real mime type
+	 * that usually also depends on the extension of the target:
+	 * ex: an iso file with the extension .iso will be seen as octet-stream
+	 * if the symlink hasn't got any extention at all */
+	while (g_file_info_get_is_symlink (info)) {
+		const gchar *target;
+		GFileInfo *tmp_info;
+		GFile *tmp_file;
+		GError *error = NULL;
+
+		target = g_file_info_get_symlink_target (info);
+		if (!g_path_is_absolute (target)) {
+			gchar *parent;
+			gchar *tmp;
+
+			tmp = g_file_get_path (file);
+			parent = g_path_get_dirname (tmp);
+			g_free (tmp);
+
+			target = g_build_filename (parent, target, NULL);
+			g_free (parent);
+		}
+
+		tmp_file = g_file_new_for_commandline_arg (target);
+		tmp_info = g_file_query_info (tmp_file,
+					      G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE ","
+					      G_FILE_ATTRIBUTE_STANDARD_IS_SYMLINK ","
+					      G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET,
+					      G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
+					      NULL,
+					      &error);
+		if (!tmp_info) {
+			g_object_unref (tmp_file);
+			break;
+		}
+
+		g_object_unref (info);
+		g_object_unref (file);
+
+		info = tmp_info;
+		file = tmp_file;
+	}
+
 	uri = g_file_get_uri (file);
 	if (g_file_query_exists (file, NULL)) {
 		const gchar *mime;
@@ -939,17 +927,14 @@ brasero_project_manager_open_uri (BraseroProjectManager *manager,
 	  	type = brasero_project_manager_open_by_mime (manager, uri, mime);
         } 
 	else {
-		window = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-	  	dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-					   	 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					   	 GTK_MESSAGE_ERROR,
-					   	 GTK_BUTTONS_CLOSE,
-					   	 "Error loading project");
-	  	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-							  _("The project '%s' does not exist."),
-							  uri);
-	  	gtk_dialog_run (GTK_DIALOG (dialog));
-	  	gtk_widget_destroy (dialog);
+		gchar *string;
+
+		string = g_strdup_printf (_("The project \"%s\" does not exist"), uri);
+		brasero_app_alert (brasero_app_get_default (),
+				   _("Error while loading the project."),
+				   string,
+				   GTK_MESSAGE_ERROR);
+		g_free (string);
 
 		type = BRASERO_PROJECT_TYPE_INVALID;
 	}
@@ -991,6 +976,7 @@ brasero_project_manager_open_cb (GtkAction *action, BraseroProjectManager *manag
 	uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (chooser));
 	gtk_widget_destroy (chooser);
 
+	manager->priv->oneshot = FALSE;
 	type = brasero_project_manager_open_uri (manager, uri);
 	g_free (uri);
 }
@@ -1000,9 +986,17 @@ brasero_project_manager_recent_clicked_cb (BraseroProjectTypeChooser *chooser,
 					   const gchar *uri,
 					   BraseroProjectManager *manager)
 {
+	manager->priv->oneshot = FALSE;
 	brasero_project_manager_open_uri (manager, uri);
 }
 
+void
+brasero_project_manager_set_oneshot (BraseroProjectManager *manager,
+				     gboolean oneshot)
+{
+	manager->priv->oneshot = oneshot;
+}
+
 void
 brasero_project_manager_empty (BraseroProjectManager *manager)
 {
@@ -1027,9 +1021,18 @@ brasero_project_manager_load_session (BraseroProjectManager *manager,
     	return TRUE;
 }
 
+static void
+brasero_project_manager_last_saved_clicked_cb (BraseroProjectTypeChooser *chooser,
+					       const gchar *path,
+					       BraseroProjectManager *manager)
+{
+	brasero_project_manager_load_session (manager, path);
+}
+
 gboolean
 brasero_project_manager_save_session (BraseroProjectManager *manager,
 				      const gchar *path,
+				      gchar **saved_uri,
 				      gboolean cancellable)
 {
     	gboolean result = FALSE;
@@ -1043,6 +1046,7 @@ brasero_project_manager_save_session (BraseroProjectManager *manager,
 		uri = g_filename_to_uri (path, NULL, NULL);
     		result = brasero_project_save_session (BRASERO_PROJECT (manager->priv->project),
 						       uri,
+						       saved_uri,
 						       cancellable);
 		g_free (uri);
 	}
@@ -1071,11 +1075,11 @@ brasero_project_manager_init (BraseroProjectManager *obj)
 
 	action = gtk_action_group_get_action (obj->priv->action_group, "NewChoose");
 	g_object_set (action,
-		      "short-label", _("New"), /* for toolbar buttons */
+		      "short-label", _("_New"), /* for toolbar buttons */
 		      NULL);
 	action = gtk_action_group_get_action (obj->priv->action_group, "Open");
 	g_object_set (action,
-		      "short-label", _("Open"), /* for toolbar buttons */
+		      "short-label", _("_Open"), /* for toolbar buttons */
 		      NULL);
 
 	/* add the project type chooser to the notebook */
@@ -1089,6 +1093,10 @@ brasero_project_manager_init (BraseroProjectManager *obj)
 			  "recent-clicked",
 			  G_CALLBACK (brasero_project_manager_recent_clicked_cb),
 			  obj);
+	g_signal_connect (type,
+			  "last-saved",
+			  G_CALLBACK (brasero_project_manager_last_saved_clicked_cb),
+			  obj);
 	gtk_notebook_prepend_page (GTK_NOTEBOOK (obj), type, NULL);
 
 	/* add the layout */
@@ -1123,7 +1131,6 @@ brasero_project_manager_init (BraseroProjectManager *obj)
 				   chooser,
 				   "Chooser",
 				   _("Browse the file system"),
-				   _("Display File Browser"),
 				   GTK_STOCK_DIRECTORY,
 				   BRASERO_LAYOUT_AUDIO|BRASERO_LAYOUT_DATA|BRASERO_LAYOUT_VIDEO);
 
@@ -1147,7 +1154,6 @@ brasero_project_manager_init (BraseroProjectManager *obj)
 				   search,
 				   "Search",
 				   _("Search files using keywords"),
-				   _("Display Search"),
 				   GTK_STOCK_FIND,
 				   BRASERO_LAYOUT_AUDIO|BRASERO_LAYOUT_DATA|BRASERO_LAYOUT_VIDEO);
 
@@ -1168,7 +1174,6 @@ brasero_project_manager_init (BraseroProjectManager *obj)
 				   playlist,
 				   "Playlist",
 				   _("Display playlists and their contents"),
-				   _("Display Playlists"),
 				   "audio-x-generic", 
 				   BRASERO_LAYOUT_AUDIO);
 
