@@ -36,16 +36,7 @@
 
 #include <gio/gio.h>
 
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtkfilechooser.h>
-#include <gtk/gtkfilechooserdialog.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkprogressbar.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkfilechooser.h>
-#include <gtk/gtkfilechooserdialog.h>
+#include <gtk/gtk.h>
 
 #include <libxml/xmlerror.h>
 #include <libxml/xmlwriter.h>
@@ -76,7 +67,6 @@
 #include "brasero-audio-disc.h"
 #include "brasero-video-disc.h"
 #include "brasero-disc-option-dialog.h"
-#include "brasero-burn-dialog.h"
 #include "brasero-utils.h"
 #include "brasero-uri-container.h"
 #include "brasero-layout-object.h"
@@ -176,6 +166,8 @@ struct BraseroProjectPrivate {
 
 	gchar *project;
 
+	gchar *cover;
+
 	gint64 sectors;
 	BraseroDisc *current;
 
@@ -562,8 +554,11 @@ brasero_project_finalize (GObject *object)
 	if (cobj->priv->project)
 		g_free (cobj->priv->project);
 
-	g_free(cobj->priv);
-	G_OBJECT_CLASS(parent_class)->finalize(object);
+	if (cobj->priv->cover)
+		g_free (cobj->priv->cover);
+
+	g_free (cobj->priv);
+	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 GtkWidget *
@@ -582,13 +577,11 @@ static void
 brasero_project_update_project_size (BraseroProject *project,
 				     guint64 sectors)
 {
-	GtkWidget *toplevel;
 	GtkWidget *status;
 	gchar *string;
 	gchar *size;
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-	status = brasero_app_get_statusbar2 (BRASERO_APP (toplevel));
+	status = brasero_app_get_statusbar2 (brasero_app_get_default ());
 
 	if (!project->priv->status_ctx)
 		project->priv->status_ctx = gtk_statusbar_get_context_id (GTK_STATUSBAR (status),
@@ -609,10 +602,11 @@ brasero_project_update_project_size (BraseroProject *project,
 		brasero_medium_get_free_space (medium,
 					       &free_space,
 					       NULL);
+
+		medium_string = g_format_size_for_display (free_space);
 		/* Translators: first %s is the size of the project and the 
 		 * second %s is the remaining free space on the disc that is
 		 * used for multisession */
-		medium_string = g_format_size_for_display (free_space);
 		size = g_strdup_printf (_("Project estimated size: %s/%s"),
 					string,
 					medium_string);
@@ -620,6 +614,7 @@ brasero_project_update_project_size (BraseroProject *project,
 	}
 	else
 		size = g_strdup_printf (_("Project estimated size: %s"), string);
+
 	g_free (string);
 
 	gtk_statusbar_push (GTK_STATUSBAR (status), project->priv->status_ctx, size);
@@ -705,8 +700,11 @@ brasero_project_get_boundaries (BraseroURIContainer *container,
 static gboolean
 _wait_for_ready_state (GtkWidget *dialog)
 {
+	gchar *current_task = NULL;
 	GtkProgressBar *progress;
 	BraseroProject *project;
+	gint remaining = 0;
+	gint initial;
 
 	project = g_object_get_data (G_OBJECT (dialog), "Project");
 	if (project->priv->oversized) {
@@ -715,9 +713,38 @@ _wait_for_ready_state (GtkWidget *dialog)
 	}
 
 	progress = g_object_get_data (G_OBJECT (dialog), "ProgressBar");
+	initial = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dialog), "Remaining"));
+	if (brasero_disc_get_status (project->priv->current, &remaining, &current_task) == BRASERO_DISC_NOT_READY) {
+		gchar *string;
+		gchar *size_str;
+
+		if (initial <= 0 || remaining <= 0)
+			gtk_progress_bar_pulse (progress);
+		else
+			gtk_progress_bar_set_fraction (progress, (gdouble) ((gdouble) (initial - remaining) / (gdouble) initial));
+
+		if (current_task) {
+			GtkWidget *current_action;
+
+			current_action = g_object_get_data (G_OBJECT (dialog), "CurrentAction");
+			string = g_strdup_printf ("<i>%s</i>", current_task);
+			g_free (current_task);
+
+			gtk_label_set_markup (GTK_LABEL (current_action), string);
+			g_free (string);
+		}
+
+		string = brasero_utils_get_sectors_string (project->priv->sectors,
+							   !BRASERO_IS_DATA_DISC (project->priv->current),
+							   TRUE,
+							   FALSE);
+
+		size_str = g_strdup_printf (_("Project estimated size: %s"), string);
+		g_free (string);
+
+		gtk_progress_bar_set_text (progress, size_str);
+		g_free (size_str);
 
-	if (brasero_disc_get_status (project->priv->current) == BRASERO_DISC_NOT_READY) {
-		gtk_progress_bar_pulse (progress);
 		return TRUE;
 	}
 
@@ -731,45 +758,76 @@ brasero_project_check_status (BraseroProject *project,
 {
 	int id;
 	int answer;
+	GtkWidget *box;
 	GtkWidget *dialog;
+	gchar *current_task;
 	GtkWidget *progress;
-	GtkWidget *toplevel;
+	gint remaining = -1;
 	BraseroDiscResult result;
+	GtkWidget *current_action;
 
-	result = brasero_disc_get_status (disc);
+	current_task = NULL;
+	result = brasero_disc_get_status (disc, &remaining, &current_task);
 	if (result != BRASERO_DISC_NOT_READY)
 		return result;
 
 	/* we are not ready to create tracks presumably because
 	 * data or audio has not finished to explore a directory
 	 * or get the metadata of a song or a film */
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-	dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-					 GTK_DIALOG_DESTROY_WITH_PARENT |
-					 GTK_DIALOG_MODAL,
-					 GTK_MESSAGE_INFO,
-					 GTK_BUTTONS_CLOSE,
-					 _("Please wait:"));
 
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Please Wait"));
+	/* This dialog can run as a standalone window when run from nautilus
+	 * to burn burn:// URI contents. */
+	dialog = brasero_app_dialog (brasero_app_get_default (),
+				     _("Please, wait until the estimation of the project size is completed."),
+				     GTK_BUTTONS_CANCEL,
+				     GTK_MESSAGE_OTHER);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("some tasks are not completed yet."));
+						  _("All files from the project need to be analysed to complete this operation."));
 
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Ongoing Tasks"));
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Project Size Estimation"));
+
+	box = gtk_vbox_new (FALSE, 4);
+	gtk_box_pack_end (GTK_BOX (GTK_DIALOG (dialog)->vbox),
+			  box,
+			  TRUE,
+			  TRUE,
+			  0);
 
 	progress = gtk_progress_bar_new ();
 	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (progress), " ");
-	gtk_box_pack_end (GTK_BOX (GTK_DIALOG (dialog)->vbox),
-			  progress,
-			  TRUE,
-			  TRUE,
-			  10);
+	gtk_box_pack_start (GTK_BOX (box),
+			    progress,
+			    TRUE,
+			    TRUE,
+			    0);
+
+	if (current_task) {
+		gchar *string;
+
+		string = g_strdup_printf ("<i>%s</i>", current_task);
+		g_free (current_task);
+
+		current_action = gtk_label_new (string);
+		g_free (string);
+	}
+	else
+		current_action = gtk_label_new ("");
+
+	gtk_label_set_use_markup (GTK_LABEL (current_action), TRUE);
+	gtk_misc_set_alignment (GTK_MISC (current_action), 0.0, 0.5);
+	gtk_box_pack_start (GTK_BOX (box),
+			    current_action,
+			    FALSE,
+			    TRUE,
+			    0);
 
 	gtk_widget_show_all (dialog);
 	gtk_progress_bar_pulse (GTK_PROGRESS_BAR (progress));
 
+	g_object_set_data (G_OBJECT (dialog), "CurrentAction", current_action);
 	g_object_set_data (G_OBJECT (dialog), "ProgressBar", progress);
+	g_object_set_data (G_OBJECT (dialog), "Remaining", GINT_TO_POINTER (remaining));
 	g_object_set_data (G_OBJECT (dialog), "Project", project);
 
 	id = g_timeout_add (100,
@@ -786,11 +844,10 @@ brasero_project_check_status (BraseroProject *project,
 	else if (project->priv->oversized)
 		return BRASERO_DISC_ERROR_SIZE;
 
-	return brasero_disc_get_status (disc);
+	return brasero_disc_get_status (disc, NULL, NULL);
 }
 
 /******************************** cover ****************************************/
-
 void
 brasero_project_set_cover_specifics (BraseroProject *self,
 				     BraseroJacketEdit *cover)
@@ -805,6 +862,7 @@ brasero_project_set_cover_specifics (BraseroProject *self,
 	brasero_disc_set_session_contents (BRASERO_DISC (self->priv->current), session);
 	brasero_jacket_edit_set_audio_tracks (BRASERO_JACKET_EDIT (cover),
 					      brasero_burn_session_get_label (session),
+					      self->priv->cover,
 					      brasero_burn_session_get_tracks (session));
 	g_object_unref (session);
 }
@@ -813,19 +871,19 @@ brasero_project_set_cover_specifics (BraseroProject *self,
 static void
 brasero_project_no_song_dialog (BraseroProject *project)
 {
-	brasero_utils_message_dialog (gtk_widget_get_toplevel (GTK_WIDGET (project)),
-				      _("Please add songs to the project."),
-				      _("The project is empty."),
-				      GTK_MESSAGE_WARNING);
+	brasero_app_alert (brasero_app_get_default (),
+			   _("Please add songs to the project."),
+			   _("The project is empty"),
+			   GTK_MESSAGE_WARNING);
 }
 
 static void
 brasero_project_no_file_dialog (BraseroProject *project)
 {
-	brasero_utils_message_dialog (gtk_widget_get_toplevel (GTK_WIDGET (project)),
-				      _("Please add files to the project."),
-				      _("The project is empty."),
-				      GTK_MESSAGE_WARNING);
+	brasero_app_alert (brasero_app_get_default (),
+			   _("Please add files to the project."),
+			   _("The project is empty"),
+			   GTK_MESSAGE_WARNING);
 }
 
 void
@@ -833,9 +891,7 @@ brasero_project_burn (BraseroProject *project)
 {
 	BraseroBurnSession *session;
 	BraseroDiscResult result;
-	GtkWidget *toplevel;
 	GtkWidget *dialog;
-	gboolean destroy;
 	gboolean success;
 
 	result = brasero_project_check_status (project, project->priv->current);
@@ -858,7 +914,6 @@ brasero_project_burn (BraseroProject *project)
 		return;
 
 	project->priv->is_burning = 1;
-	destroy = FALSE;
 
 	/* This is to stop the preview widget from playing */
 	brasero_uri_container_uri_selected (BRASERO_URI_CONTAINER (project));
@@ -868,46 +923,39 @@ brasero_project_burn (BraseroProject *project)
 	brasero_disc_option_dialog_set_disc (BRASERO_DISC_OPTION_DIALOG (dialog),
 					     project->priv->current);
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
-	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
-	gtk_widget_show (dialog);
+	brasero_app_set_toplevel (brasero_app_get_default (), GTK_WINDOW (dialog));
 
 	result = gtk_dialog_run (GTK_DIALOG (dialog));
-	if (result != GTK_RESPONSE_OK)
+	if (result != GTK_RESPONSE_OK) {
+		gtk_widget_destroy (dialog);
 		goto end;
+	}
 
 	session = brasero_disc_option_dialog_get_session (BRASERO_DISC_OPTION_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
-	/* set the label for the session */
+	/* set the label/cover for the session */
 	brasero_burn_session_set_label (session, gtk_entry_get_text (GTK_ENTRY (project->priv->name_display)));
 
+	if (project->priv->cover) {
+		GValue *value;
+
+		value = g_new0 (GValue, 1);
+		g_value_init (value, G_TYPE_STRING);
+		g_value_set_string (value, project->priv->cover);
+		brasero_burn_session_tag_add (session,
+					      BRASERO_COVER_URI,
+					      value);
+	}
+
 	/* now setup the burn dialog */
-	dialog = brasero_burn_dialog_new ();
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
-	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-
-	gtk_widget_hide (toplevel);
-	gtk_widget_show (dialog);
-
-	success = brasero_burn_dialog_run (BRASERO_BURN_DIALOG (dialog),
-					   session,
-					   &destroy);
-	g_object_unref (session);
+	success = brasero_app_burn (brasero_app_get_default (), session);
 
     	project->priv->burnt = success;
 
 end:
 
 	project->priv->is_burning = 0;
-	gtk_widget_destroy (dialog);
-
-	if (destroy)
-		gtk_widget_destroy (toplevel);
-	else
-		gtk_widget_show (toplevel);
 }
 
 /********************************     ******************************************/
@@ -935,6 +983,11 @@ brasero_project_switch (BraseroProject *project, BraseroProjectType type)
 		project->priv->project = NULL;
 	}
 
+	if (project->priv->cover) {
+		g_free (project->priv->cover);
+		project->priv->cover = NULL;
+	}
+
 	client = gconf_client_get_default ();
 
 	/* remove the buttons from the "toolbar" */
@@ -1034,24 +1087,16 @@ gboolean
 brasero_project_confirm_switch (BraseroProject *project)
 {
 	GtkWidget *dialog;
-	GtkWidget *toplevel;
 	GtkResponseType answer;
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-
 	if (project->priv->project) {
 		if (!project->priv->modified)
 			return TRUE;
 
-		dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-						 GTK_DIALOG_DESTROY_WITH_PARENT |
-						 GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_WARNING,
-						 GTK_BUTTONS_CANCEL,
-						 _("Do you really want to create a new project and discard the changes to current one?"));
-
-		
-		gtk_window_set_title (GTK_WINDOW (dialog), _("Unsaved Project"));
+		dialog = brasero_app_dialog (brasero_app_get_default (),
+					     _("Do you really want to create a new project and discard the changes to current one?"),
+					     GTK_BUTTONS_CANCEL,
+					     GTK_MESSAGE_WARNING);
 
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 							  _("If you choose to create a new project, all changes made will be lost."));
@@ -1063,16 +1108,10 @@ brasero_project_confirm_switch (BraseroProject *project)
 		if (project->priv->empty)
 			return TRUE;
 
-		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-		dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-						 GTK_DIALOG_DESTROY_WITH_PARENT |
-						 GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_WARNING,
-						 GTK_BUTTONS_CANCEL,
-						 _("Do you really want to create a new project and discard the current one?"));
-
-		
-		gtk_window_set_title (GTK_WINDOW (dialog), _("New Project"));
+		dialog = brasero_app_dialog (brasero_app_get_default (),
+					     _("Do you really want to create a new project and discard the current one?"),
+					     GTK_BUTTONS_CANCEL,
+					     GTK_MESSAGE_WARNING);
 
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 							  _("If you choose to create a new project, "
@@ -1097,13 +1136,17 @@ brasero_project_set_none (BraseroProject *project)
 {
 	GtkAction *action;
 	GtkWidget *status;
-	GtkWidget *toplevel;
 
 	if (project->priv->project) {
 		g_free (project->priv->project);
 		project->priv->project = NULL;
 	}
 
+	if (project->priv->cover) {
+		g_free (project->priv->cover);
+		project->priv->cover = NULL;
+	}
+
 	if (project->priv->chooser) {
 		gtk_widget_destroy (project->priv->chooser);
 		project->priv->chooser = NULL;
@@ -1130,8 +1173,7 @@ brasero_project_set_none (BraseroProject *project)
 		gtk_ui_manager_remove_ui (project->priv->manager,
 					  project->priv->merge_id);
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-	status = brasero_app_get_statusbar2 (BRASERO_APP (toplevel));
+	status = brasero_app_get_statusbar2 (brasero_app_get_default ());
 
 	if (project->priv->status_ctx)
 		gtk_statusbar_pop (GTK_STATUSBAR (status), project->priv->status_ctx);
@@ -1148,7 +1190,7 @@ brasero_project_contents_changed_cb (BraseroDisc *disc,
 
 	project->priv->empty = (nb_files == 0);
 
-	if (brasero_disc_get_status (disc) != BRASERO_DISC_LOADING)
+	if (brasero_disc_get_status (disc, NULL, NULL) != BRASERO_DISC_LOADING)
 		project->priv->modified = 1;
 
 	brasero_project_set_remove_button_state (project);
@@ -1444,27 +1486,20 @@ brasero_project_empty_cb (GtkAction *action, BraseroProject *project)
 {
 	if (!project->priv->empty) {
 		GtkWidget *dialog;
-		GtkWidget *toplevel;
 		GtkResponseType answer;
 
-		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-		dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-						 GTK_DIALOG_DESTROY_WITH_PARENT |
-						 GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_WARNING,
-						 GTK_BUTTONS_CANCEL,
-						 _("Do you really want to empty the current project?"));
-
-		
-		gtk_window_set_title (GTK_WINDOW (dialog), _("Empty Project"));
+		dialog = brasero_app_dialog (brasero_app_get_default (),
+					      _("Do you really want to empty the current project?"),
+					     GTK_BUTTONS_CANCEL,
+					     GTK_MESSAGE_WARNING);
 
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 							  _("Emptying a project will remove all files already added. "
 							    "All the work will be lost. "
 							    "Note that files will not be deleted from their own location, "
 							    "just no longer listed here."));
-		/* Translators: "empty" is a verb here */
 		gtk_dialog_add_button (GTK_DIALOG (dialog),
+					/* Translators: "empty" is a verb here */
 				       _("E_mpty Project"),
 				       GTK_RESPONSE_OK);
 
@@ -1515,7 +1550,7 @@ brasero_project_register_ui (BraseroProject *project, GtkUIManager *manager)
 	
 	action = gtk_action_group_get_action (project->priv->project_group, "Save");
 	g_object_set (action,
-		      "short-label", _("Save"), /* for toolbar buttons */
+		      "short-label", _("_Save"), /* for toolbar buttons */
 		      NULL);
 	gtk_action_set_sensitive (action, FALSE);
 	action = gtk_action_group_get_action (project->priv->project_group, "SaveAs");
@@ -1526,12 +1561,12 @@ brasero_project_register_ui (BraseroProject *project, GtkUIManager *manager)
 	action = gtk_action_group_get_action (project->priv->project_group, "Add");
 	gtk_action_set_sensitive (action, FALSE);
 	g_object_set (action,
-		      "short-label", _("Add"), /* for toolbar buttons */
+		      "short-label", _("_Add"), /* for toolbar buttons */
 		      NULL);
 	action = gtk_action_group_get_action (project->priv->project_group, "DeleteProject");
 	gtk_action_set_sensitive (action, FALSE);
 	g_object_set (action,
-		      "short-label", _("Remove"), /* for toolbar buttons */
+		      "short-label", _("_Remove"), /* for toolbar buttons */
 		      NULL);
 	action = gtk_action_group_get_action (project->priv->project_group, "DeleteAll");
 	gtk_action_set_sensitive (action, FALSE);
@@ -1540,7 +1575,6 @@ brasero_project_register_ui (BraseroProject *project, GtkUIManager *manager)
 }
 
 /******************************* common to save/open ***************************/
-
 static void
 brasero_project_add_to_recents (BraseroProject *project,
 				const gchar *uri,
@@ -1585,8 +1619,10 @@ brasero_project_set_uri (BraseroProject *project,
 
 	uri = uri ? uri : project->priv->project;
 
-    	/* add it to recent manager */
-    	brasero_project_add_to_recents (project, uri, TRUE);
+	/* add it to recent manager */
+	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
+	if (brasero_app_is_running (brasero_app_get_default ()))
+		brasero_project_add_to_recents (project, uri, TRUE);
 
 	/* update the name of the main window */
     	BRASERO_GET_BASENAME_FOR_DISPLAY (uri, name);
@@ -1601,7 +1637,6 @@ brasero_project_set_uri (BraseroProject *project,
  
 	g_free (name);
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
 	gtk_window_set_title (GTK_WINDOW (toplevel), title);
 	g_free (title);
 
@@ -1615,10 +1650,10 @@ static void
 brasero_project_invalid_project_dialog (BraseroProject *project,
 					const char *reason)
 {
-	brasero_utils_message_dialog (gtk_widget_get_toplevel (GTK_WIDGET (project)),
-				      _("Error while loading the project:"),
-				      reason,
-				      GTK_MESSAGE_ERROR);
+	brasero_app_alert (brasero_app_get_default (),
+			   _("Error while loading the project."),
+			   reason,
+			   GTK_MESSAGE_ERROR);
 }
 
 static gboolean
@@ -1812,6 +1847,75 @@ _read_audio_track (xmlDocPtr project,
 			song->end = (gint64) g_ascii_strtoull (end, NULL, 10);
 			g_free (end);
 		}
+		else if (!xmlStrcmp (uris->name, (const xmlChar *) "title")) {
+			xmlChar *title;
+
+			title = xmlNodeListGetString (project,
+						      uris->xmlChildrenNode,
+						      1);
+			if (!title)
+				goto error;
+
+			if (!song->info)
+				song->info = g_new0 (BraseroSongInfo, 1);
+
+			if (song->info->title)
+				g_free (song->info->title);
+
+			song->info->title = g_uri_unescape_string ((char *) title, NULL);
+			g_free (title);
+		}
+		else if (!xmlStrcmp (uris->name, (const xmlChar *) "artist")) {
+			xmlChar *artist;
+
+			artist = xmlNodeListGetString (project,
+						      uris->xmlChildrenNode,
+						      1);
+			if (!artist)
+				goto error;
+
+			if (!song->info)
+				song->info = g_new0 (BraseroSongInfo, 1);
+
+			if (song->info->artist)
+				g_free (song->info->artist);
+
+			song->info->artist = g_uri_unescape_string ((char *) artist, NULL);
+			g_free (artist);
+		}
+		else if (!xmlStrcmp (uris->name, (const xmlChar *) "composer")) {
+			xmlChar *composer;
+
+			composer = xmlNodeListGetString (project,
+							 uris->xmlChildrenNode,
+							 1);
+			if (!composer)
+				goto error;
+
+			if (!song->info)
+				song->info = g_new0 (BraseroSongInfo, 1);
+
+			if (song->info->composer)
+				g_free (song->info->composer);
+
+			song->info->composer = g_uri_unescape_string ((char *) composer, NULL);
+			g_free (composer);
+		}
+		else if (!xmlStrcmp (uris->name, (const xmlChar *) "isrc")) {
+			gchar *isrc;
+
+			isrc = (gchar *) xmlNodeListGetString (project,
+							       uris->xmlChildrenNode,
+							       1);
+			if (!isrc)
+				goto error;
+
+			if (!song->info)
+				song->info = g_new0 (BraseroSongInfo, 1);
+
+			song->info->isrc = (gint) g_ascii_strtod (isrc, NULL);
+			g_free (isrc);
+		}
 		else if (uris->type == XML_ELEMENT_NODE)
 			goto error;
 
@@ -1894,6 +1998,7 @@ static gboolean
 brasero_project_open_project_xml (BraseroProject *proj,
 				  const gchar *uri,
 				  gchar **label,
+				  gchar **cover,
 				  BraseroDiscTrack **track,
 				  gboolean warn_user)
 {
@@ -1913,7 +2018,7 @@ brasero_project_open_project_xml (BraseroProject *proj,
 
 	if (!project) {
 	    	if (warn_user)
-			brasero_project_invalid_project_dialog (proj, _("the project could not be opened."));
+			brasero_project_invalid_project_dialog (proj, _("The project could not be opened."));
 
 		return FALSE;
 	}
@@ -1922,7 +2027,7 @@ brasero_project_open_project_xml (BraseroProject *proj,
 	item = xmlDocGetRootElement (project);
 	if (!item) {
 	    	if (warn_user)
-			brasero_project_invalid_project_dialog (proj, _("the file is empty."));
+			brasero_project_invalid_project_dialog (proj, _("The file is empty."));
 
 		xmlFreeDoc (project);
 		return FALSE;
@@ -1944,6 +2049,18 @@ brasero_project_open_project_xml (BraseroProject *proj,
 			if (!(*label))
 				goto error;
 		}
+		else if (!xmlStrcmp (item->name, (const xmlChar *) "cover")) {
+			xmlChar *escaped;
+
+			escaped = xmlNodeListGetString (project,
+							item->xmlChildrenNode,
+							1);
+			if (!escaped)
+				goto error;
+
+			*cover = g_uri_unescape_string ((char *) escaped, NULL);
+			g_free (escaped);
+		}
 		else if (!xmlStrcmp (item->name, (const xmlChar *) "track")) {
 			if (track_node)
 				goto error;
@@ -1960,7 +2077,7 @@ brasero_project_open_project_xml (BraseroProject *proj,
 	xmlFreeDoc (project);
 
 	if (!retval && warn_user)
-		brasero_project_invalid_project_dialog (proj, _("it doesn't seem to be a valid Brasero project."));
+		brasero_project_invalid_project_dialog (proj, _("It does not seem to be a valid Brasero project."));
 
 	return retval;
 
@@ -1968,7 +2085,7 @@ error:
 
 	xmlFreeDoc (project);
     	if (warn_user)
-		brasero_project_invalid_project_dialog (proj, _("it doesn't seem to be a valid Brasero project."));
+		brasero_project_invalid_project_dialog (proj, _("It does not seem to be a valid Brasero project."));
 
 	return FALSE;
 }
@@ -1980,11 +2097,12 @@ brasero_project_open_project (BraseroProject *project,
 	BraseroDiscTrack *track = NULL;
 	BraseroProjectType type;
 	gchar *label = NULL;
+	gchar *cover = NULL;
 
 	if (!uri || *uri =='\0')
 		return BRASERO_PROJECT_TYPE_INVALID;
 
-	if (!brasero_project_open_project_xml (project, uri, &label, &track, TRUE))
+	if (!brasero_project_open_project_xml (project, uri, &label, &cover, &track, TRUE))
 		return BRASERO_PROJECT_TYPE_INVALID;
 
 	brasero_project_update_project_size (project, 0);
@@ -2002,15 +2120,24 @@ brasero_project_open_project (BraseroProject *project,
 
 	brasero_project_switch (project, type);
 
-	g_signal_handlers_block_by_func (project->priv->name_display,
-					 brasero_project_name_changed_cb,
-					 project);
-	gtk_entry_set_text (GTK_ENTRY (project->priv->name_display), label);
-	g_free (label);
+	if (label) {
+		g_signal_handlers_block_by_func (project->priv->name_display,
+						 brasero_project_name_changed_cb,
+						 project);
+		gtk_entry_set_text (GTK_ENTRY (project->priv->name_display), label);
+		g_free (label);
 
-	g_signal_handlers_unblock_by_func (project->priv->name_display,
-					   brasero_project_name_changed_cb,
-					   project);
+		g_signal_handlers_unblock_by_func (project->priv->name_display,
+						   brasero_project_name_changed_cb,
+						   project);
+	}
+
+	if (cover) {
+		if (project->priv->cover)
+			g_free (project->priv->cover);
+
+		project->priv->cover = cover;
+	}
 
 	brasero_disc_load_track (project->priv->current, track);
 	brasero_track_free (track);
@@ -2088,7 +2215,7 @@ brasero_project_open_audio_playlist_project (BraseroProject *proj,
 	result = totem_pl_parser_parse (parser, uri, FALSE);
 	if (result != TOTEM_PL_PARSER_RESULT_SUCCESS) {
 		if (warn_user)
-			brasero_project_invalid_project_dialog (proj, _("it doesn't seem to be a valid Brasero project."));
+			brasero_project_invalid_project_dialog (proj, _("It does not seem to be a valid Brasero project."));
 
 		brasero_track_free (new_track);
 	}
@@ -2143,8 +2270,9 @@ brasero_project_load_session (BraseroProject *project, const gchar *uri)
 	BraseroDiscTrack *track = NULL;
 	BraseroProjectType type;
 	gchar *label;
+	gchar *cover;
 
-	if (!brasero_project_open_project_xml (project, uri, &label, &track, FALSE))
+	if (!brasero_project_open_project_xml (project, uri, &label, &cover, &track, FALSE))
 		return BRASERO_PROJECT_TYPE_INVALID;
 
 	if (track->type == BRASERO_DISC_TRACK_AUDIO)
@@ -2183,10 +2311,10 @@ brasero_project_not_saved_dialog (BraseroProject *project)
 	xmlError *error;
 
 	error = xmlGetLastError ();
-	brasero_utils_message_dialog (gtk_widget_get_toplevel (GTK_WIDGET (project)),
-				      _("Your project has not been saved:"),
-				      error?error->message:_("Unknown error."),
-				      GTK_MESSAGE_ERROR);
+	brasero_app_alert (brasero_app_get_default (),
+			   _("Your project has not been saved."),
+			   error? error->message:_("An unknown error occured"),
+			   GTK_MESSAGE_ERROR);
 	xmlResetLastError ();
 }
 
@@ -2195,31 +2323,25 @@ brasero_project_save_project_dialog (BraseroProject *project,
 				     gboolean show_cancel)
 {
 	GtkWidget *dialog;
-	GtkWidget *toplevel;
 	GtkResponseType result;
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-	dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-					 GTK_DIALOG_DESTROY_WITH_PARENT|
-					 GTK_DIALOG_MODAL,
-					 GTK_MESSAGE_WARNING,
-					 GTK_BUTTONS_NONE,
-					 _("Save the changes of current project before closing?"));
-
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Modified Project"));
+	dialog = brasero_app_dialog (brasero_app_get_default (),
+				     _("Save the changes of current project before closing?"),
+				     GTK_BUTTONS_NONE,
+				     GTK_MESSAGE_WARNING);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 						  _("If you don't save, changes will be permanently lost."));
 
 	if (show_cancel)
 		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-					_("Cl_ose without saving"), GTK_RESPONSE_NO,
+					_("Cl_ose Without Saving"), GTK_RESPONSE_NO,
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					GTK_STOCK_SAVE, GTK_RESPONSE_YES,
 					NULL);
 	else
 		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-					_("Cl_ose without saving"), GTK_RESPONSE_NO,
+					_("Cl_ose Without Saving"), GTK_RESPONSE_NO,
 					GTK_STOCK_SAVE, GTK_RESPONSE_YES,
 					NULL);
 
@@ -2247,11 +2369,15 @@ _save_audio_track_xml (xmlTextWriter *project,
 
 	for (iter = track->contents.tracks; iter; iter = iter->next) {
 		BraseroDiscSong *song;
+		BraseroSongInfo *info;
 		xmlChar *escaped;
 		gchar *start;
+		gchar *isrc;
 		gchar *end;
 
 		song = iter->data;
+		info = song->info;
+
 		escaped = (unsigned char *) g_uri_escape_string (song->uri, NULL, FALSE);
 		success = xmlTextWriterWriteElement (project,
 						    (xmlChar *) "uri",
@@ -2274,25 +2400,74 @@ _save_audio_track_xml (xmlTextWriter *project,
 				return FALSE;
 		}
 
-		/* start of the song */
-		start = g_strdup_printf ("%"G_GINT64_FORMAT, song->start);
-		success = xmlTextWriterWriteElement (project,
-						     (xmlChar *) "start",
-						     (xmlChar *) start);
+		if (song->end > 0) {
+			/* start of the song */
+			start = g_strdup_printf ("%"G_GINT64_FORMAT, song->start);
+			success = xmlTextWriterWriteElement (project,
+							     (xmlChar *) "start",
+							     (xmlChar *) start);
 
-		g_free (start);
-		if (success == -1)
-			return FALSE;
+			g_free (start);
+			if (success == -1)
+				return FALSE;
 
-		/* end of the song */
-		end = g_strdup_printf ("%"G_GINT64_FORMAT, song->end);
-		success = xmlTextWriterWriteElement (project,
-						     (xmlChar *) "end",
-						     (xmlChar *) end);
+			/* end of the song */
+			end = g_strdup_printf ("%"G_GINT64_FORMAT, song->end);
+			success = xmlTextWriterWriteElement (project,
+							     (xmlChar *) "end",
+							     (xmlChar *) end);
 
-		g_free (end);
-		if (success == -1)
-			return FALSE;
+			g_free (end);
+			if (success == -1)
+				return FALSE;
+		}
+
+		if (!info)
+			continue;
+
+		if (info->title) {
+			escaped = (unsigned char *) g_uri_escape_string (info->title, NULL, FALSE);
+			success = xmlTextWriterWriteElement (project,
+							    (xmlChar *) "title",
+							     escaped);
+			g_free (escaped);
+
+			if (success == -1)
+				return FALSE;
+		}
+
+		if (info->artist) {
+			escaped = (unsigned char *) g_uri_escape_string (info->artist, NULL, FALSE);
+			success = xmlTextWriterWriteElement (project,
+							    (xmlChar *) "artist",
+							     escaped);
+			g_free (escaped);
+
+			if (success == -1)
+				return FALSE;
+		}
+
+		if (info->composer) {
+			escaped = (unsigned char *) g_uri_escape_string (info->composer, NULL, FALSE);
+			success = xmlTextWriterWriteElement (project,
+							    (xmlChar *) "composer",
+							     escaped);
+			g_free (escaped);
+
+			if (success == -1)
+				return FALSE;
+		}
+
+		if (info->isrc) {
+			isrc = g_strdup_printf ("%d", info->isrc);
+			success = xmlTextWriterWriteElement (project,
+							     (xmlChar *) "isrc",
+							     (xmlChar *) isrc);
+
+			g_free (isrc);
+			if (success == -1)
+				return FALSE;
+		}
 	}
 
 	return TRUE;
@@ -2368,8 +2543,8 @@ brasero_project_save_project_xml (BraseroProject *proj,
 	gint success;
     	gchar *path;
 
-    	path = g_filename_from_uri (uri, NULL, NULL);
-    	if (!path)
+	path = g_filename_from_uri (uri, NULL, NULL);
+	if (!path)
 		return FALSE;
 
 	project = xmlNewTextWriterFilename (path, 0);
@@ -2409,6 +2584,19 @@ brasero_project_save_project_xml (BraseroProject *proj,
 	if (success < 0)
 		goto error;
 
+	if (proj->priv->cover) {
+		gchar *escaped;
+
+		escaped = g_uri_escape_string (proj->priv->cover, NULL, FALSE);
+		success = xmlTextWriterWriteElement (project,
+						     (xmlChar *) "cover",
+						     (xmlChar *) escaped);
+		g_free (escaped);
+
+		if (success < 0)
+			goto error;
+	}
+
 	success = xmlTextWriterStartElement (project, (xmlChar *) "track");
 	if (success < 0)
 		goto error;
@@ -2551,7 +2739,7 @@ brasero_project_save_audio_project_plain_text (BraseroProject *proj,
 				goto error;
 
 			/* Translators: %s is an artist */
-			string = g_strdup_printf (_(" by %s"), info->artist);
+			string = g_strdup_printf (" by %s", info->artist);
 			written = fwrite (string, 1, strlen (string), file);
 			if (written != strlen (string)) {
 				g_free (string);
@@ -2690,6 +2878,7 @@ brasero_project_save_project_real (BraseroProject *project,
 				   BraseroProjectSave save_type)
 {
 	BraseroDiscResult result;
+	BraseroProjectType type;
 	BraseroDiscTrack track;
 
 	g_return_val_if_fail (uri != NULL || project->priv->project != NULL, FALSE);
@@ -2713,9 +2902,20 @@ brasero_project_save_project_real (BraseroProject *project,
 		return FALSE;
 	}
 
+	if (track.type == BRASERO_DISC_TRACK_AUDIO)
+		type = BRASERO_PROJECT_TYPE_AUDIO;
+	else if (track.type == BRASERO_DISC_TRACK_DATA)
+		type = BRASERO_PROJECT_TYPE_DATA;
+	else if (track.type == BRASERO_DISC_TRACK_VIDEO)
+		type = BRASERO_PROJECT_TYPE_VIDEO;
+	else {
+		brasero_track_clear (&track);
+		return BRASERO_PROJECT_TYPE_INVALID;
+	}
+
 	if (save_type == BRASERO_PROJECT_SAVE_XML
 	||  track.type == BRASERO_DISC_TRACK_DATA) {
-		brasero_project_set_uri (project, uri, track.type);
+		brasero_project_set_uri (project, uri, type);
 		if (!brasero_project_save_project_xml (project,
 						       uri ? uri : project->priv->project,
 						       &track,
@@ -2852,16 +3052,27 @@ brasero_project_save_project_as (BraseroProject *project)
 gboolean
 brasero_project_save_session (BraseroProject *project,
 			      const gchar *uri,
+			      gchar **saved_uri,
 			      gboolean show_cancel)
 {
     	BraseroDiscTrack track;
 
+	if (!project->priv->current) {
+		if (saved_uri)
+			*saved_uri = NULL;
+
+		return FALSE;
+	}
+
 	if (project->priv->project) {
 		GtkResponseType answer;
 
 		if (!project->priv->modified) {
 			/* there is a saved project but unmodified.
 			 * No need to ask anything */
+			if (saved_uri)
+				*saved_uri = g_strdup (project->priv->project);
+
 			return FALSE;
 		}
 
@@ -2870,24 +3081,31 @@ brasero_project_save_session (BraseroProject *project,
 		if (answer == GTK_RESPONSE_CANCEL)
 			return TRUE;
 
-		if (answer != GTK_RESPONSE_YES)
+		if (answer != GTK_RESPONSE_YES) {
+			if (saved_uri)
+				*saved_uri = NULL;
+
 			return FALSE;
+		}
 
-		brasero_project_save_project_real (project, NULL, BRASERO_PROJECT_SAVE_XML);
+		if (!brasero_project_save_project_real (project, NULL, BRASERO_PROJECT_SAVE_XML))
+			return TRUE;
+
+		if (saved_uri)
+			*saved_uri = g_strdup (project->priv->project);
 
-		/* return FALSE since this is not a tmp project */
 		return FALSE;
 	}
 
 	if (project->priv->empty) {
 		/* the project is empty anyway. No need to ask anything.
 		 * return FALSE since this is not a tmp project */
+		if (saved_uri)
+			*saved_uri = NULL;
+
 		return FALSE;
 	}
 
-    	if (!project->priv->current)
-		return FALSE;
-
     	if (project->priv->burnt) {
 		GtkResponseType answer;
 
@@ -2897,28 +3115,42 @@ brasero_project_save_session (BraseroProject *project,
 		if (answer == GTK_RESPONSE_CANCEL)
 			return TRUE;
 
-		if (answer != GTK_RESPONSE_YES)
+		if (answer != GTK_RESPONSE_YES) {
+			if (saved_uri)
+				*saved_uri = NULL;
+
 			return FALSE;
+		}
 
-		brasero_project_save_project_as (project);
+		if (!brasero_project_save_project_as (project))
+			return TRUE;
+
+		if (saved_uri)
+			*saved_uri = g_strdup (project->priv->project);
 
-		/* return FALSE since this is not a tmp project */
 		return FALSE;
 	}
 
-    	if (!uri)
+    	if (!uri) {
+		if (saved_uri)
+			*saved_uri = NULL;
+
 		return FALSE;
+	}
 
     	bzero (&track, sizeof (track));
-	if (brasero_disc_get_track (project->priv->current, &track) == BRASERO_DISC_OK)
-		brasero_project_save_project_xml (project,
-						  uri,
-						  &track,
-						  FALSE);
+	if (brasero_disc_get_track (project->priv->current, &track) == BRASERO_DISC_OK) {
+		if (!brasero_project_save_project_xml (project,
+						       uri,
+						       &track,
+						       FALSE))
+			return TRUE;
+	}
 
 	brasero_track_clear (&track);
 
-	/* let the application close itself anyway. It wasn't asked by the user
-	 * and it may get into some critical shutdown */
+	if (saved_uri)
+		*saved_uri = g_strdup (uri);
+
     	return FALSE;
 }
