@@ -40,29 +40,11 @@
 
 #include <gio/gio.h>
 
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkfilefilter.h>
-#include <gtk/gtkselection.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkcellrenderer.h>
-#include <gtk/gtkcellrendererpixbuf.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcellrendererprogress.h>
-#include <gtk/gtktreeviewcolumn.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreemodelfilter.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkcomboboxentry.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtk.h>
 
 #include <beagle/beagle.h>
 
+#include "brasero-app.h"
 #include "brasero-utils.h"
 #include "brasero-search-entry.h"
 #include "brasero-mime-filter.h"
@@ -339,7 +321,7 @@ brasero_search_init (BraseroSearch *obj)
 	box = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (obj), box, FALSE, FALSE, 0);
 
-	button = brasero_utils_make_button (_("Previous results"),
+	button = brasero_utils_make_button (_("Previous Results"),
 					    GTK_STOCK_GO_BACK,
 					    NULL,
 					    GTK_ICON_SIZE_BUTTON);
@@ -360,7 +342,7 @@ brasero_search_init (BraseroSearch *obj)
 	gtk_box_pack_start (GTK_BOX (box), label, TRUE, TRUE, 0);
 	obj->priv->results_label = label;
 
-	button = brasero_utils_make_button (_("Next results"),
+	button = brasero_utils_make_button (_("Next Results"),
 					    GTK_STOCK_GO_FORWARD,
 					    NULL,
 					    GTK_ICON_SIZE_BUTTON);
@@ -595,9 +577,9 @@ brasero_search_new ()
 		gtk_widget_set_sensitive (GTK_WIDGET (obj), FALSE);
 
 		/* we will retry in 10 seconds */
-		obj->priv->id = g_timeout_add (10000,
-					       (GSourceFunc) brasero_search_try_again,
-					       obj);
+		obj->priv->id = g_timeout_add_seconds (10,
+						       (GSourceFunc) brasero_search_try_again,
+						       obj);
 	}
 
 	return GTK_WIDGET (obj);
@@ -1044,18 +1026,10 @@ brasero_search_beagle_finished_cb (BeagleQuery *query,
 static void
 brasero_search_beagle_error_dialog (BraseroSearch *search, GError *error)
 {
-	GtkWidget *toplevel;
-
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (search));
-	if (!GTK_WIDGET_TOPLEVEL (toplevel)) {
-		g_warning ("Error querying beagle : %s\n", error->message);
-		return;
-	}
-
-	brasero_utils_message_dialog (toplevel,
-				      _("Error querying beagle:"),
-				      error->message,
-				      GTK_MESSAGE_ERROR);
+	brasero_app_alert (brasero_app_get_default (),
+			   _("Error querying beagle."),
+			   error->message,
+			   GTK_MESSAGE_ERROR);
 }
 
 static void
