@@ -40,13 +40,14 @@
 
 #include <gst/gst.h>
 
+#include "brasero-app.h"
 #include "brasero-utils.h"
 #include "brasero-data-tree-model.h"
 
 #define BRASERO_ERROR brasero_error_quark()
 
 static GHashTable *stringsH = NULL;
-G_LOCK_DEFINE (strings_mutex);
+G_LOCK_DEFINE_STATIC (stringsH);
 
 static gboolean
 brasero_utils_clear_strings_cb (gchar *string,
@@ -61,13 +62,13 @@ static void
 brasero_utils_free (void)
 {
 	if (stringsH) {
-		G_LOCK (strings_mutex);
+		G_LOCK (stringsH);
 		g_hash_table_foreach_remove (stringsH,
 					     (GHRFunc) brasero_utils_clear_strings_cb,
 					     NULL);
 		g_hash_table_destroy (stringsH);
 		stringsH = NULL;
-		G_UNLOCK (strings_mutex);
+		G_UNLOCK (stringsH);
 	}
 }
 
@@ -111,7 +112,7 @@ brasero_utils_register_string (const gchar *string)
 		return NULL;
 	}
 
-	G_LOCK (strings_mutex);
+	G_LOCK (stringsH);
 
 	if (!stringsH) {
 		stringsH = g_hash_table_new (g_str_hash, g_str_equal);
@@ -128,7 +129,7 @@ brasero_utils_register_string (const gchar *string)
 		g_hash_table_insert (stringsH,
 				     key,
 				     GINT_TO_POINTER (1));
-		G_UNLOCK (strings_mutex);
+		G_UNLOCK (stringsH);
 		return key;
 	}
 
@@ -137,7 +138,7 @@ brasero_utils_register_string (const gchar *string)
 			     key,
 			     GINT_TO_POINTER (ref));
 
-	G_UNLOCK (strings_mutex);
+	G_UNLOCK (stringsH);
 	return key;
 }
 
@@ -153,10 +154,10 @@ brasero_utils_unregister_string (const gchar *string)
 		return;
 	}
 
-	G_LOCK (strings_mutex);
+	G_LOCK (stringsH);
 
 	if (!stringsH) {
-		G_UNLOCK (strings_mutex);
+		G_UNLOCK (stringsH);
 		return;
 	}
 
@@ -165,7 +166,7 @@ brasero_utils_unregister_string (const gchar *string)
 						&key,
 						&reftmp);
 	if (!success) {
-		G_UNLOCK (strings_mutex);
+		G_UNLOCK (stringsH);
 		return;
 	}
 
@@ -178,7 +179,7 @@ brasero_utils_unregister_string (const gchar *string)
 		g_free (key);
 	}
 
-	G_UNLOCK (strings_mutex);
+	G_UNLOCK (stringsH);
 }
 
 gchar *
@@ -261,7 +262,9 @@ brasero_utils_get_size_string (gint64 dsize,
 	int unit;
 	int size;
 	int remain = 0;
-	const char *units[] = { "", N_("KiB"), N_("MiB"), N_("GiB") };
+
+	if (with_unit)
+		return g_format_size_for_display (dsize);
 
 	if (dsize < 1024) {
 		unit = BRASERO_UTILS_NO_UNIT;
@@ -294,18 +297,7 @@ brasero_utils_get_size_string (gint64 dsize,
 		size -= remains;
 	}
 
-	if (with_unit == TRUE && unit != BRASERO_UTILS_NO_UNIT) {
-		if (remain)
-			return g_strdup_printf ("%i.%i %s",
-						size,
-						remain,
-						_(units[unit]));
-		else
-			return g_strdup_printf ("%i %s",
-						size,
-						_(units[unit]));
-	}
-	else if (remain)
+	if (remain)
 		return g_strdup_printf ("%i.%i",
 					size,
 					remain);
@@ -344,15 +336,23 @@ brasero_utils_pack_properties_list (const gchar *title, GSList *list)
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox);
-	gtk_box_pack_end (GTK_BOX (vbox_main), hbox, TRUE, TRUE, 6);
+	gtk_box_pack_end (GTK_BOX (vbox_main),
+			  hbox,
+			  TRUE,
+			  TRUE,
+			  6);
 
 	label = gtk_label_new ("\t");
 	gtk_widget_show (label);
-	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
 
 	vbox_prop = gtk_vbox_new (FALSE, 6);
 	gtk_widget_show (vbox_prop);
-	gtk_box_pack_start (GTK_BOX (hbox), vbox_prop, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox),
+			    vbox_prop,
+			    TRUE,
+			    TRUE,
+			    0);
 
 	for (iter = list; iter; iter = iter->next) {
 		gtk_box_pack_start (GTK_BOX (vbox_prop),
@@ -376,6 +376,8 @@ brasero_utils_pack_properties_list (const gchar *title, GSList *list)
 		gtk_container_add (GTK_CONTAINER (frame), vbox_main);
 		return frame;
 	}
+	else
+		gtk_container_set_border_width (GTK_CONTAINER (vbox_main), 6);
 
 	return vbox_main;
 }
@@ -467,25 +469,14 @@ brasero_utils_launch_app (GtkWidget *widget,
 		uri = item->data;
 
 		if (!g_app_info_launch_default_for_uri (uri, NULL, &error)) {
-			GtkWidget *dialog;
-			GtkWidget *toplevel;
-
-			toplevel = gtk_widget_get_toplevel (GTK_WIDGET (widget));
-			dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-							 GTK_DIALOG_DESTROY_WITH_PARENT|
-							 GTK_DIALOG_MODAL,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_CLOSE,
-							 _("This file can't be opened:"));
-
-			gtk_window_set_title (GTK_WINDOW (dialog), _("File Error"));
-
-			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-								  error->message);
-
-			gtk_dialog_run (GTK_DIALOG (dialog));
-			gtk_widget_destroy (dialog);
+			gchar *string;
 
+			string = g_strdup_printf ("\"%s\" could not be opened", uri);
+			brasero_app_alert (brasero_app_get_default (),
+					   string,
+					   error->message,
+					   GTK_MESSAGE_ERROR);
+			g_free (string);
 			g_error_free (error);
 			continue;
 		}
@@ -517,3 +508,45 @@ brasero_utils_validate_utf8 (const gchar *name)
 
 	return retval;
 }
+
+GtkWidget *
+brasero_utils_create_message_dialog (GtkWidget *parent,
+				     const gchar *primary_message,
+				     const gchar *secondary_message,
+				     GtkMessageType type)
+{
+	GtkWidget *message;
+
+	message = gtk_message_dialog_new (GTK_WINDOW (parent),
+					  GTK_DIALOG_MODAL |
+					  GTK_DIALOG_DESTROY_WITH_PARENT,
+					  type,
+					  GTK_BUTTONS_CLOSE,
+					  primary_message);
+
+	gtk_window_set_title (GTK_WINDOW (message), "");
+
+	if (secondary_message)
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
+							  "%s.",
+							  secondary_message);
+
+	return message;
+}
+
+void
+brasero_utils_message_dialog (GtkWidget *parent,
+			      const gchar *primary_message,
+			      const gchar *secondary_message,
+			      GtkMessageType type)
+{
+	GtkWidget *message;
+
+	message = brasero_utils_create_message_dialog (parent,
+						       primary_message,
+						       secondary_message,
+						       type);
+
+	gtk_dialog_run (GTK_DIALOG (message));
+	gtk_widget_destroy (message);
+}
