@@ -86,6 +86,54 @@ enum {
 
 G_DEFINE_TYPE (BraseroDrive, brasero_drive, G_TYPE_OBJECT);
 
+GDrive *
+brasero_drive_get_gdrive (BraseroDrive *drive)
+{
+	const gchar *volume_path = NULL;
+	GVolumeMonitor *monitor;
+	GDrive *gdrive = NULL;
+	GList *drives;
+	GList *iter;
+
+#if defined(HAVE_STRUCT_USCSI_CMD)
+	volume_path = brasero_drive_get_block_device (drive);
+#else
+	volume_path = brasero_drive_get_device (drive);
+#endif
+
+	/* NOTE: medium-monitor already holds a reference for GVolumeMonitor */
+	monitor = g_volume_monitor_get ();
+	drives = g_volume_monitor_get_connected_drives (monitor);
+	g_object_unref (monitor);
+
+	for (iter = drives; iter; iter = iter->next) {
+		gchar *device_path;
+		GDrive *tmp;
+
+		tmp = iter->data;
+		device_path = g_drive_get_identifier (tmp, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+		if (!device_path)
+			continue;
+
+		BRASERO_BURN_LOG ("Found drive %s", device_path);
+		if (!strcmp (device_path, volume_path)) {
+			gdrive = tmp;
+			g_free (device_path);
+			g_object_ref (gdrive);
+			break;
+		}
+
+		g_free (device_path);
+	}
+	g_list_foreach (drives, (GFunc) g_object_unref, NULL);
+	g_list_free (drives);
+
+	if (!drive)
+		BRASERO_BURN_LOG ("No drive found for medium");
+
+	return gdrive;
+}
+
 gboolean
 brasero_drive_get_bus_target_lun (BraseroDrive *self,
 				  guint *bus,
@@ -264,11 +312,12 @@ brasero_drive_get_display_name (BraseroDrive *self)
 
 	priv = BRASERO_DRIVE_PRIVATE (self);
 
-	/* Translators: This is a fake drive, a file, and means that when we're
-	 * writing, we're writing to a file and create an image on the hard 
-	 * drive. */
-	if (!priv->udi)
-		return g_strdup (_("Image File"));;
+	if (!priv->udi) {
+		/* Translators: This is a fake drive, a file, and means that
+		 * when we're writing, we're writing to a file and create an
+		 * image on the hard drive. */
+		return g_strdup (_("Image File"));
+	}
 
 	watch = brasero_hal_watch_get_default ();
 	ctx = brasero_hal_watch_get_ctx (watch);
@@ -413,6 +462,15 @@ brasero_drive_medium_probed (BraseroMedium *medium,
 		       priv->medium);
 }
 
+gboolean
+brasero_drive_probing (BraseroDrive *self)
+{
+	BraseroDrivePrivate *priv;
+
+	priv = BRASERO_DRIVE_PRIVATE (self);
+	return priv->probed != TRUE;
+}
+
 void
 brasero_drive_reprobe (BraseroDrive *self)
 {
@@ -447,6 +505,31 @@ brasero_drive_reprobe (BraseroDrive *self)
 			  self);
 }
 
+#if 0
+
+void
+brasero_drive_hal_reprobe (BraseroDrive *self)
+{
+	BraseroDrivePrivate *priv;
+	BraseroHALWatch *watch;
+	LibHalContext *ctx;
+	DBusError error;
+
+	priv = BRASERO_DRIVE_PRIVATE (self);
+
+	watch = brasero_hal_watch_get_default ();
+	ctx = brasero_hal_watch_get_ctx (watch);
+
+	dbus_error_init (&error);
+	if (!libhal_device_reprobe (ctx, priv->udi, &error)) {
+		BRASERO_BURN_LOG ("libhal_device_reprobe () failed %s",
+				  error.message);
+		dbus_error_free (&error);
+	}			      
+}
+
+#endif
+
 static void
 brasero_drive_check_medium_inside (BraseroDrive *self)
 {
@@ -501,8 +584,10 @@ brasero_drive_check_medium_inside (BraseroDrive *self)
 			       0,
 			       medium);
 		g_object_unref (medium);
-		priv->probed = FALSE;
+		priv->probed = TRUE;
 	}
+	else
+		priv->probed = TRUE;
 }
 
 static void
@@ -515,11 +600,15 @@ brasero_drive_medium_inside_property_changed_cb (BraseroHALWatch *watch,
 
 	priv = BRASERO_DRIVE_PRIVATE (drive);
 
-	if (key && strcmp (key, "storage.removable.media_available"))
+	if (key && strcmp (key, "storage.removable.media_available")) {
+		priv->probed = TRUE;
 		return;
+	}
 
-	if (udi && strcmp (udi, priv->udi))
+	if (udi && strcmp (udi, priv->udi)) {
+		priv->probed = TRUE;
 		return;
+	}
 
 	brasero_drive_check_medium_inside (drive);
 }
@@ -542,7 +631,7 @@ brasero_drive_init_real (BraseroDrive *drive)
 							priv->udi,
 							BLOCK_DEVICE,
 							NULL);
-	if (priv->path [0] == '\0') {
+	if (priv->path && priv->path [0] == '\0') {
 		g_free (priv->path);
 		priv->path = NULL;
 	}
@@ -551,7 +640,7 @@ brasero_drive_init_real (BraseroDrive *drive)
 							      priv->udi,
 							      "block.device",
 							      NULL);
-	if (priv->block_path [0] == '\0') {
+	if (priv->block_path && priv->block_path [0] == '\0') {
 		g_free (priv->block_path);
 		priv->block_path = NULL;
 	}
@@ -629,6 +718,7 @@ brasero_drive_set_property (GObject *object,
 	case PROP_UDI:
 		priv->udi = g_strdup (g_value_get_string (value));
 		if (!priv->udi) {
+			priv->probed = TRUE;
 			priv->medium = g_object_new (BRASERO_TYPE_VOLUME,
 						     "drive", object,
 						     NULL);
