@@ -63,6 +63,8 @@ struct _BraseroChecksumImagePrivate {
 
 	/* this is for the thread and the end of it */
 	GThread *thread;
+	GMutex *mutex;
+	GCond *cond;
 	gint end_id;
 
 	guint cancel;
@@ -106,8 +108,7 @@ brasero_checksum_image_read (BraseroChecksumImage *self,
 				g_set_error (error,
 					     BRASERO_BURN_ERROR,
 					     BRASERO_BURN_ERROR_GENERAL,
-					     _("data could not be read from the pipe (%i: %s)"),
-					     errsv,
+					     _("Data could not be read (%s)"),
 					     g_strerror (errsv));
 				return -1;
 			}
@@ -157,8 +158,7 @@ brasero_checksum_image_write (BraseroChecksumImage *self,
 				g_set_error (error,
 					     BRASERO_BURN_ERROR,
 					     BRASERO_BURN_ERROR_GENERAL,
-					     _("the data couldn't be written to the pipe (%i: %s)"),
-					     errsv,
+					     _("Data could not be written (%s)"),
 					     g_strerror (errsv));
 				return BRASERO_BURN_ERR;
 			}
@@ -193,10 +193,10 @@ brasero_checksum_image_checksum (BraseroChecksumImage *self,
 	result = BRASERO_BURN_OK;
 	while (1) {
 		read_bytes = brasero_checksum_image_read (self,
-						  fd_in,
-						  buffer,
-						  sizeof (buffer),
-						  error);
+							  fd_in,
+							  buffer,
+							  sizeof (buffer),
+							  error);
 		if (read_bytes == -2)
 			return BRASERO_BURN_CANCEL;
 
@@ -210,9 +210,9 @@ brasero_checksum_image_checksum (BraseroChecksumImage *self,
 		 * that we don't need to output the received data */
 		if (fd_out > 0) {
 			result = brasero_checksum_image_write (self,
-						       fd_out,
-						       buffer,
-						       read_bytes, error);
+							       fd_out,
+							       buffer,
+							       read_bytes, error);
 			if (result != BRASERO_BURN_OK)
 				break;
 		}
@@ -270,8 +270,8 @@ brasero_checksum_image_checksum_file_input (BraseroChecksumImage *self,
 	if (!path) {
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
-			     BRASERO_BURN_ERROR_GENERAL,
-			     _("the image is not local"));
+			     BRASERO_BURN_ERROR_FILE_NOT_LOCAL,
+			     _("The file is not stored locally"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -291,10 +291,13 @@ brasero_checksum_image_checksum_file_input (BraseroChecksumImage *self,
 		name = g_path_get_basename (path);
 
                 errsv = errno;
+
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("the file %s couldn't be read (%s)"),
+			     /* Translators: first %s is the filename, second %s
+			      * is the error generated from errno */
+			     _("\"%s\" could not be opened (%s)"),
 			     name,
 			     g_strerror (errsv));
 		g_free (name);
@@ -317,9 +320,9 @@ brasero_checksum_image_create_checksum (BraseroChecksumImage *self,
 					GError **error)
 {
 	BraseroBurnResult result;
-	BraseroChecksumImagePrivate *priv;
 	BraseroTrack *track = NULL;
 	GChecksumType checksum_type;
+	BraseroChecksumImagePrivate *priv;
 
 	priv = BRASERO_CHECKSUM_IMAGE_PRIVATE (self);
 
@@ -373,20 +376,33 @@ brasero_checksum_image_create_checksum (BraseroChecksumImage *self,
 	return BRASERO_BURN_OK;
 }
 
+static BraseroChecksumType
+brasero_checksum_get_checksum_type (void)
+{
+	GConfClient *client;
+	GChecksumType checksum_type;
+
+	client = gconf_client_get_default ();
+	checksum_type = gconf_client_get_int (client, GCONF_KEY_CHECKSUM_TYPE, NULL);
+	g_object_unref (client);
+
+	if (!checksum_type)
+		checksum_type = BRASERO_CHECKSUM_MD5;
+
+	return checksum_type;
+}
+
 static BraseroBurnResult
 brasero_checksum_image_image_and_checksum (BraseroChecksumImage *self,
 					   GError **error)
 {
-	GConfClient *client;
 	BraseroBurnResult result;
 	GChecksumType checksum_type;
 	BraseroChecksumImagePrivate *priv;
 
 	priv = BRASERO_CHECKSUM_IMAGE_PRIVATE (self);
-	client = gconf_client_get_default ();
-	priv->checksum_type = gconf_client_get_int (client, GCONF_KEY_CHECKSUM_TYPE, NULL);
-	g_object_unref (client);
 
+	priv->checksum_type = brasero_checksum_get_checksum_type ();
 	if (priv->checksum_type == BRASERO_CHECKSUM_NONE)
 		checksum_type = G_CHECKSUM_MD5;
 	else if (priv->checksum_type & BRASERO_CHECKSUM_MD5)
@@ -416,10 +432,14 @@ brasero_checksum_image_image_and_checksum (BraseroChecksumImage *self,
 		if (result != BRASERO_BURN_OK)
 			return result;
 
-		result = brasero_checksum_image_checksum_file_input (self, checksum_type, error);
+		result = brasero_checksum_image_checksum_file_input (self,
+								     checksum_type,
+								     error);
 	}
 	else
-		result = brasero_checksum_image_checksum_fd_input (self, checksum_type, error);
+		result = brasero_checksum_image_checksum_fd_input (self,
+								   checksum_type,
+								   error);
 
 	return result;
 }
@@ -470,7 +490,7 @@ brasero_checksum_image_end (gpointer data)
 	 * potential previous one. */
 	checksum = g_checksum_get_string (priv->checksum);
 	BRASERO_JOB_LOG (self,
-			 "setting new checksum (type = %i) %s (%s before)",
+			 "Setting new checksum (type = %i) %s (%s before)",
 			 priv->checksum_type,
 			 checksum,
 			 brasero_track_get_checksum (track));
@@ -492,7 +512,7 @@ error:
 
 	error = g_error_new (BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_BAD_CHECKSUM,
-			     _("some files may be corrupted on the disc"));
+			     _("Some files may be corrupted on the disc"));
 	brasero_job_error (BRASERO_JOB (self), error);
 	return FALSE;
 }
@@ -559,7 +579,12 @@ brasero_checksum_image_thread (gpointer data)
 						brasero_checksum_image_destroy);
 	}
 
+	/* End thread */
+	g_mutex_lock (priv->mutex);
 	priv->thread = NULL;
+	g_cond_signal (priv->cond);
+	g_mutex_unlock (priv->mutex);
+
 	g_thread_exit (NULL);
 	return NULL;
 }
@@ -586,10 +611,13 @@ brasero_checksum_image_start (BraseroJob *job,
 
 	/* we start a thread for the exploration of the graft points */
 	priv = BRASERO_CHECKSUM_IMAGE_PRIVATE (job);
+	g_mutex_lock (priv->mutex);
 	priv->thread = g_thread_create (brasero_checksum_image_thread,
 					BRASERO_CHECKSUM_IMAGE (job),
 					TRUE,
 					error);
+	g_mutex_unlock (priv->mutex);
+
 	if (!priv->thread)
 		return BRASERO_BURN_ERR;
 
@@ -608,8 +636,10 @@ brasero_checksum_image_activate (BraseroJob *job,
 	brasero_job_get_action (job, &action);
 
 	if (action == BRASERO_JOB_ACTION_IMAGE
-	&&  brasero_track_get_checksum_type (track) != BRASERO_CHECKSUM_NONE) {
-		BRASERO_JOB_LOG (job, "There is a checksum already");
+	&&  brasero_track_get_checksum_type (track) == brasero_checksum_get_checksum_type ()) {
+		BRASERO_JOB_LOG (job,
+				 "There is a checksum already %d",
+				 brasero_track_get_checksum_type (track));
 		/* if there is a checksum already, if so no need to redo one */
 		return BRASERO_BURN_NOT_RUNNING;
 	}
@@ -651,12 +681,14 @@ brasero_checksum_image_stop (BraseroJob *job,
 
 	priv = BRASERO_CHECKSUM_IMAGE_PRIVATE (job);
 
+	g_mutex_lock (priv->mutex);
 	if (priv->thread) {
 		priv->cancel = 1;
-		g_thread_join (priv->thread);
+		g_cond_wait (priv->cond, priv->mutex);
 		priv->cancel = 0;
 		priv->thread = NULL;
 	}
+	g_mutex_unlock (priv->mutex);
 
 	if (priv->end_id) {
 		g_source_remove (priv->end_id);
@@ -673,7 +705,13 @@ brasero_checksum_image_stop (BraseroJob *job,
 
 static void
 brasero_checksum_image_init (BraseroChecksumImage *obj)
-{ }
+{	BraseroChecksumImagePrivate *priv;
+
+	priv = BRASERO_CHECKSUM_IMAGE_PRIVATE (obj);
+
+	priv->mutex = g_mutex_new ();
+	priv->cond = g_cond_new ();
+}
 
 static void
 brasero_checksum_image_finalize (GObject *object)
@@ -682,12 +720,14 @@ brasero_checksum_image_finalize (GObject *object)
 	
 	priv = BRASERO_CHECKSUM_IMAGE_PRIVATE (object);
 
+	g_mutex_lock (priv->mutex);
 	if (priv->thread) {
 		priv->cancel = 1;
-		g_thread_join (priv->thread);
+		g_cond_wait (priv->cond, priv->mutex);
 		priv->cancel = 0;
 		priv->thread = NULL;
 	}
+	g_mutex_unlock (priv->mutex);
 
 	if (priv->end_id) {
 		g_source_remove (priv->end_id);
@@ -699,6 +739,16 @@ brasero_checksum_image_finalize (GObject *object)
 		priv->checksum = NULL;
 	}
 
+	if (priv->mutex) {
+		g_mutex_free (priv->mutex);
+		priv->mutex = NULL;
+	}
+
+	if (priv->cond) {
+		g_cond_free (priv->cond);
+		priv->cond = NULL;
+	}
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -726,8 +776,11 @@ brasero_checksum_image_export_caps (BraseroPlugin *plugin, gchar **error)
 	BraseroPluginConfOption *checksum_type;
 
 	brasero_plugin_define (plugin,
-			       "Image checksum",
-			       _("allows to check data integrity on disc after it is burnt"),
+			       /* Translators: this is the name of the plugin
+				* which will be translated only when it needs
+				* displaying. */
+			       N_("Image Checksum"),
+			       _("Allows to check data integrity on disc after it is burnt"),
 			       "Philippe Rouquier",
 			       0);
 
