@@ -54,6 +54,8 @@ BRASERO_PLUGIN_BOILERPLATE (BraseroDvdcss, brasero_dvdcss, BRASERO_TYPE_JOB, Bra
 struct _BraseroDvdcssPrivate {
 	GError *error;
 	GThread *thread;
+	GMutex *mutex;
+	GCond *cond;
 	guint thread_id;
 
 	guint cancel:1;
@@ -62,7 +64,7 @@ typedef struct _BraseroDvdcssPrivate BraseroDvdcssPrivate;
 
 #define BRASERO_DVDCSS_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), BRASERO_TYPE_DVDCSS, BraseroDvdcssPrivate))
 
-#define BRASERO_DVDCSS_I_BLOCKS	16
+#define BRASERO_DVDCSS_I_BLOCKS	16ULL
 
 static GObjectClass *parent_class = NULL;
 
@@ -117,14 +119,14 @@ error_doesnt_exist:
 	g_set_error (error,
 		     BRASERO_BURN_ERROR,
 		     BRASERO_BURN_ERROR_GENERAL,
-		     _("encrypted DVD: please, install libdvdcss version 1.2.x"));
+		     _("Encrypted DVD: please, install libdvdcss version 1.2.x"));
 	return FALSE;
 
 error_version:
 	g_set_error (error,
 		     BRASERO_BURN_ERROR,
 		     BRASERO_BURN_ERROR_GENERAL,
-		     _("libdvdcss version %s is not supported.\nPlease, install libdvdcss version 1.2.x"),
+		     _("Libdvdcss version %s is not supported.\nPlease, install libdvdcss version 1.2.x"),
 		     dvdcss_interface_2);
 	g_module_close (module);
 	return FALSE;
@@ -134,7 +136,7 @@ error_loading:
 	g_set_error (error,
 		     BRASERO_BURN_ERROR,
 		     BRASERO_BURN_ERROR_GENERAL,
-		     _("libdvdcss couldn't be loaded properly"));
+		     _("Libdvdcss could not be loaded properly"));
 	g_module_close (module);
 	return FALSE;
 }
@@ -206,12 +208,13 @@ brasero_dvdcss_write_sector_to_fd (BraseroDvdcss *self,
 
 		if (written != bytes_remaining) {
 			if (errno != EINTR && errno != EAGAIN) {
+                                int errsv = errno;
+
 				/* unrecoverable error */
 				priv->error = g_error_new (BRASERO_BURN_ERROR,
 							   BRASERO_BURN_ERROR_GENERAL,
-							   _("the data couldn't be written to the pipe (%i: %s)"),
-							   errno,
-							   strerror (errno));
+							   _("Data could not be written (%s)"),
+							   g_strerror (errsv));
 				return BRASERO_BURN_ERR;
 			}
 
@@ -341,7 +344,7 @@ brasero_dvdcss_write_image_thread (gpointer data)
 	if (volume_size == -1) {
 		priv->error = g_error_new (BRASERO_BURN_ERROR,
 					   BRASERO_BURN_ERROR_GENERAL,
-					   _("the size of the volume couln't be retrieved"));
+					   _("The size of the volume could not be retrieved"));
 		goto end;
 	}
 
@@ -350,7 +353,7 @@ brasero_dvdcss_write_image_thread (gpointer data)
 	if (!handle) {
 		priv->error = g_error_new (BRASERO_BURN_ERROR,
 					   BRASERO_BURN_ERROR_GENERAL,
-					   _("DVD could not be opened"));
+					   _("Video DVD could not be opened"));
 		goto end;
 	}
 
@@ -368,7 +371,7 @@ brasero_dvdcss_write_image_thread (gpointer data)
 	if (dvdcss_seek (handle, 0, DVDCSS_NOFLAGS) != 0) {
 		priv->error = g_error_new (BRASERO_BURN_ERROR,
 					   BRASERO_BURN_ERROR_GENERAL,
-					   _("Error reading video DVD (%s)"),
+					   _("Error while reading video DVD (%s)"),
 					   dvdcss_error (handle));
 		goto end;
 	}
@@ -391,15 +394,16 @@ brasero_dvdcss_write_image_thread (gpointer data)
 		g_free (output);
 
 		if (!output_fd) {
-			priv->error = g_error_new (BRASERO_BURN_ERROR,
-						   BRASERO_BURN_ERROR_GENERAL,
-						   strerror (errno));
+			priv->error = g_error_new_literal (BRASERO_BURN_ERROR,
+							   BRASERO_BURN_ERROR_GENERAL,
+							   g_strerror (errno));
 			goto end;
 		}
 	}
 
 	while (remaining_sectors) {
-		gint flag, num_blocks, data_size;
+		gint flag;
+		guint64 num_blocks, data_size;
 
 		if (priv->cancel)
 			break;
@@ -428,7 +432,7 @@ brasero_dvdcss_write_image_thread (gpointer data)
 			&&  dvdcss_seek (handle, written_sectors, DVDCSS_SEEK_KEY) != written_sectors) {
 				priv->error = g_error_new (BRASERO_BURN_ERROR,
 							   BRASERO_BURN_ERROR_GENERAL,
-							   _("Error reading video DVD (%s)"),
+							   _("Error while reading video DVD (%s)"),
 							   dvdcss_error (handle));
 				break;
 			}
@@ -448,7 +452,7 @@ brasero_dvdcss_write_image_thread (gpointer data)
 		if (dvdcss_read (handle, buf, num_blocks, flag) != num_blocks) {
 			priv->error = g_error_new (BRASERO_BURN_ERROR,
 						   BRASERO_BURN_ERROR_GENERAL,
-						   _("Error reading video DVD (%s)"),
+						   _("Error while reading video DVD (%s)"),
 						   dvdcss_error (handle));
 			break;
 		}
@@ -456,11 +460,12 @@ brasero_dvdcss_write_image_thread (gpointer data)
 		data_size = num_blocks * DVDCSS_BLOCK_SIZE;
 		if (output_fd) {
 			if (fwrite (buf, 1, data_size, output_fd) != data_size) {
+                                int errsv = errno;
+
 				priv->error = g_error_new (BRASERO_BURN_ERROR,
 							   BRASERO_BURN_ERROR_GENERAL,
-							   _("the data couldn't be written to the file (%i: %s)"),
-							   errno,
-							   strerror (errno));
+							   _("Data could not be written (%s)"),
+							   g_strerror (errsv));
 				break;
 			}
 		}
@@ -470,7 +475,6 @@ brasero_dvdcss_write_image_thread (gpointer data)
 			result = brasero_dvdcss_write_sector_to_fd (self,
 								    buf,
 								    data_size);
-
 			if (result != BRASERO_BURN_OK)
 				break;
 		}
@@ -502,7 +506,12 @@ end:
 	if (!priv->cancel)
 		priv->thread_id = g_idle_add (brasero_dvdcss_thread_finished, self);
 
+	/* End thread */
+	g_mutex_lock (priv->mutex);
 	priv->thread = NULL;
+	g_cond_signal (priv->cond);
+	g_mutex_unlock (priv->mutex);
+
 	g_thread_exit (NULL);
 
 	return NULL;
@@ -541,10 +550,12 @@ brasero_dvdcss_start (BraseroJob *job,
 	if (!brasero_dvdcss_library_init (error))
 		return BRASERO_BURN_ERR;
 
+	g_mutex_lock (priv->mutex);
 	priv->thread = g_thread_create (brasero_dvdcss_write_image_thread,
 					self,
 					TRUE,
 					error);
+	g_mutex_unlock (priv->mutex);
 
 	if (!priv->thread)
 		return BRASERO_BURN_ERR;
@@ -558,11 +569,14 @@ brasero_dvdcss_stop_real (BraseroDvdcss *self)
 	BraseroDvdcssPrivate *priv;
 
 	priv = BRASERO_DVDCSS_PRIVATE (self);
+
+	g_mutex_lock (priv->mutex);
 	if (priv->thread) {
 		priv->cancel = 1;
-		g_thread_join (priv->thread);
+		g_cond_wait (priv->cond, priv->mutex);
 		priv->cancel = 0;
 	}
+	g_mutex_unlock (priv->mutex);
 
 	if (priv->thread_id) {
 		g_source_remove (priv->thread_id);
@@ -604,12 +618,34 @@ brasero_dvdcss_class_init (BraseroDvdcssClass *klass)
 
 static void
 brasero_dvdcss_init (BraseroDvdcss *obj)
-{ }
+{
+	BraseroDvdcssPrivate *priv;
+
+	priv = BRASERO_DVDCSS_PRIVATE (obj);
+
+	priv->mutex = g_mutex_new ();
+	priv->cond = g_cond_new ();
+}
 
 static void
 brasero_dvdcss_finalize (GObject *object)
 {
+	BraseroDvdcssPrivate *priv;
+
+	priv = BRASERO_DVDCSS_PRIVATE (object);
+
 	brasero_dvdcss_stop_real (BRASERO_DVDCSS (object));
+
+	if (priv->mutex) {
+		g_mutex_free (priv->mutex);
+		priv->mutex = NULL;
+	}
+
+	if (priv->cond) {
+		g_cond_free (priv->cond);
+		priv->cond = NULL;
+	}
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -641,7 +677,7 @@ brasero_dvdcss_export_caps (BraseroPlugin *plugin, gchar **error)
 					 BRASERO_PLUGIN_IO_ACCEPT_PIPE,
 					 BRASERO_IMAGE_FORMAT_BIN);
 	input = brasero_caps_disc_new (BRASERO_MEDIUM_DVD|
-				       BRASERO_MEDIUM_DVD_DL|
+				       BRASERO_MEDIUM_DUAL_L|
 				       BRASERO_MEDIUM_ROM|
 				       BRASERO_MEDIUM_CLOSED|
 				       BRASERO_MEDIUM_HAS_DATA|
