@@ -60,6 +60,8 @@ struct _BraseroLibisofsPrivate {
 
 	GError *error;
 	GThread *thread;
+	GMutex *mutex;
+	GCond *cond;
 	guint thread_id;
 
 	guint cancel:1;
@@ -139,12 +141,13 @@ brasero_libisofs_write_sector_to_fd (BraseroLibisofs *self,
 
 		if (written != bytes_remaining) {
 			if (errno != EINTR && errno != EAGAIN) {
+                                int errsv = errno;
+
 				/* unrecoverable error */
 				priv->error = g_error_new (BRASERO_BURN_ERROR,
 							   BRASERO_BURN_ERROR_GENERAL,
-							   _("the data couldn't be written to the pipe (%i: %s)"),
-							   errno,
-							   strerror (errno));
+							   _("Data could not be written (%s)"),
+							   g_strerror (errsv));
 				return BRASERO_BURN_ERR;
 			}
 
@@ -212,9 +215,16 @@ brasero_libisofs_write_image_to_file_thread (BraseroLibisofs *self)
 	brasero_job_get_image_output (BRASERO_JOB (self), &output, NULL);
 	file = fopen (output, "w");
 	if (!file) {
-		priv->error = g_error_new (BRASERO_BURN_ERROR,
-					   BRASERO_BURN_ERROR_GENERAL,
-					   strerror (errno));
+		int errnum = errno;
+
+		if (errno == EACCES)
+			priv->error = g_error_new_literal (BRASERO_BURN_ERROR,
+							   BRASERO_BURN_ERROR_PERMISSION,
+							   "You do not have the required permission to write at this location");
+		else
+			priv->error = g_error_new_literal (BRASERO_BURN_ERROR,
+							   BRASERO_BURN_ERROR_GENERAL,
+							   g_strerror (errnum));
 		return;
 	}
 
@@ -233,11 +243,12 @@ brasero_libisofs_write_image_to_file_thread (BraseroLibisofs *self)
 			break;
 
 		if (fwrite (buf, 1, sector_size, file) != sector_size) {
+                        int errsv = errno;
+
 			priv->error = g_error_new (BRASERO_BURN_ERROR,
 						   BRASERO_BURN_ERROR_GENERAL,
-						   _("the data couldn't be written to the file (%i: %s)"),
-						   errno,
-						   strerror (errno));
+						   _("Data could not be written (%s)"),
+						   g_strerror (errsv));
 			break;
 		}
 
@@ -270,7 +281,12 @@ brasero_libisofs_thread_started (gpointer data)
 	if (!priv->cancel)
 		priv->thread_id = g_idle_add (brasero_libisofs_thread_finished, self);
 
+	/* End thread */
+	g_mutex_lock (priv->mutex);
 	priv->thread = NULL;
+	g_cond_signal (priv->cond);
+	g_mutex_unlock (priv->mutex);
+
 	g_thread_exit (NULL);
 	return NULL;
 }
@@ -290,16 +306,18 @@ brasero_libisofs_create_image (BraseroLibisofs *self,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("Libisofs can't be initialized."));
+			     _("Libisofs could not be initialized."));
 		return BRASERO_BURN_ERR;
 	}
 
 	iso_set_msgs_severities ("NEVER", "ALL", "brasero (libisofs)");
 
+	g_mutex_lock (priv->mutex);
 	priv->thread = g_thread_create (brasero_libisofs_thread_started,
 					self,
 					TRUE,
 					error);
+	g_mutex_unlock (priv->mutex);
 	if (!priv->thread)
 		return BRASERO_BURN_ERR;
 
@@ -430,7 +448,7 @@ brasero_libisofs_import_last_session (BraseroLibisofs *self,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("No read options could be created."));
+			     _("Read options could not be created"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -452,8 +470,8 @@ brasero_libisofs_import_last_session (BraseroLibisofs *self,
 	if (result < 0) {
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
-			     BRASERO_BURN_ERROR_GENERAL,
-			     _("Image import failed."));	
+			     BRASERO_BURN_ERROR_IMAGE_LAST_SESSION,
+			     _("Last session import failed"));	
 		return BRASERO_BURN_ERR;
 	}
 
@@ -506,7 +524,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 	if (!iso_image_new (label, &image)) {
 		priv->error = g_error_new (BRASERO_BURN_ERROR,
 					   BRASERO_BURN_ERROR_GENERAL,
-					   _("Volume could not be created."));
+					   _("Volume could not be created"));
 		g_free (label);
 		goto end;
 	}
@@ -614,7 +632,8 @@ brasero_libisofs_create_volume_thread (gpointer data)
 			g_free (path_name);
 			priv->error = g_error_new (BRASERO_BURN_ERROR,
 						   BRASERO_BURN_ERROR_GENERAL,
-						   _("a parent for the path (%s) could not be found in the tree"),
+						   /* Translators: %s is the path */
+						   _("No parent could be found in the tree for the path \"%s\""),
 						   graft->path);
 			goto end;
 		}
@@ -626,12 +645,18 @@ brasero_libisofs_create_volume_thread (gpointer data)
 			gchar *local_path;
 			IsoDirIter *sibling;
 
-			local_path = g_filename_from_uri (graft->uri, NULL, NULL);
+			/* graft->uri can be a path or a URI */
+			if (graft->uri [0] == '/')
+				local_path = g_strdup (graft->uri);
+			else if (g_str_has_prefix (graft->uri, "file://"))
+				local_path = g_filename_from_uri (graft->uri, NULL, NULL);
+			else
+				local_path = NULL;
+
 			if (!local_path){
 				priv->error = g_error_new (BRASERO_BURN_ERROR,
-							   BRASERO_BURN_ERROR_GENERAL,
-							   _("non local file %s"),
-							   G_STRLOC);
+							   BRASERO_BURN_ERROR_FILE_NOT_LOCAL,
+							   _("The file is not stored locally"));
 				g_free (path_name);
 				goto end;
 			}
@@ -673,9 +698,8 @@ brasero_libisofs_create_volume_thread (gpointer data)
 							 result);
 					priv->error = g_error_new (BRASERO_BURN_ERROR,
 								   BRASERO_BURN_ERROR_GENERAL,
-								   _("libisofs reported an error while adding directory %s (%x)"),
-								   graft->path,
-								   result);
+								   _("Libisofs reported an error while creating directory \"%s\""),
+								   graft->path);
 					g_free (path_name);
 					goto end;
 				}
@@ -689,7 +713,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 							 result);
 					priv->error = g_error_new (BRASERO_BURN_ERROR,
 								   BRASERO_BURN_ERROR_GENERAL,
-								   _("libisofs reported an error while adding contents to directory %s (%x)"),
+								   _("Libisofs reported an error while adding contents to directory \"%s\" (%x)"),
 								   graft->path,
 								   result);
 					g_free (path_name);
@@ -711,7 +735,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 							 err);
 					priv->error = g_error_new (BRASERO_BURN_ERROR,
 								   BRASERO_BURN_ERROR_GENERAL,
-								   _("libisofs reported an error while adding file %s"),
+								   _("Libisofs reported an error while adding file at path \"%s\""),
 								   graft->path);
 					g_free (path_name);
 					goto end;
@@ -727,7 +751,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 								 err);
 						priv->error = g_error_new (BRASERO_BURN_ERROR,
 									   BRASERO_BURN_ERROR_GENERAL,
-									   _("libisofs reported an error while adding file %s"),
+									   _("Libisofs reported an error while adding file at path \"%s\""),
 									   graft->path);
 						g_free (path_name);
 						goto end;
@@ -740,7 +764,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 		else if (iso_tree_add_new_dir (ISO_DIR (parent), path_name, NULL) < 0) {
 			priv->error = g_error_new (BRASERO_BURN_ERROR,
 						   BRASERO_BURN_ERROR_GENERAL,
-						   _("libisofs reported an error while creating directory %s"),
+						   _("Libisofs reported an error while creating directory \"%s\""),
 						   graft->path);
 			g_free (path_name);
 			goto end;
@@ -789,7 +813,12 @@ end:
 	if (!priv->cancel)
 		priv->thread_id = g_idle_add (brasero_libisofs_create_volume_thread_finished, self);
 
+	/* End thread */
+	g_mutex_lock (priv->mutex);
 	priv->thread = NULL;
+	g_cond_signal (priv->cond);
+	g_mutex_unlock (priv->mutex);
+
 	g_thread_exit (NULL);
 
 	return NULL;
@@ -808,15 +837,17 @@ brasero_libisofs_create_volume (BraseroLibisofs *self, GError **error)
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("Libisofs can't be initialized."));
+			     _("Libisofs could not be initialized."));
 		return BRASERO_BURN_ERR;
 	}
 
 	iso_set_msgs_severities ("NEVER", "ALL", "brasero (libisofs)");
+	g_mutex_lock (priv->mutex);
 	priv->thread = g_thread_create (brasero_libisofs_create_volume_thread,
 					self,
 					TRUE,
 					error);
+	g_mutex_unlock (priv->mutex);
 	if (!priv->thread)
 		return BRASERO_BURN_ERR;
 
@@ -866,14 +897,16 @@ brasero_libisofs_stop_real (BraseroLibisofs *self)
 		priv->ctx = NULL;
 	}
 
+	g_mutex_lock (priv->mutex);
 	if (priv->thread) {
 		if (priv->libburn_src)
 			priv->libburn_src->cancel (priv->libburn_src);
 
 		priv->cancel = 1;
-		g_thread_join (priv->thread);
+		g_cond_wait (priv->cond, priv->mutex);
 		priv->cancel = 0;
 	}
+	g_mutex_unlock (priv->mutex);
 
 	if (priv->thread_id) {
 		g_source_remove (priv->thread_id);
@@ -914,7 +947,13 @@ brasero_libisofs_class_init (BraseroLibisofsClass *klass)
 
 static void
 brasero_libisofs_init (BraseroLibisofs *obj)
-{ }
+{
+	BraseroLibisofsPrivate *priv;
+
+	priv = BRASERO_LIBISOFS_PRIVATE (obj);
+	priv->mutex = g_mutex_new ();
+	priv->cond = g_cond_new ();
+}
 
 static void
 brasero_libisofs_clean_output (BraseroLibisofs *self)
@@ -936,12 +975,24 @@ static void
 brasero_libisofs_finalize (GObject *object)
 {
 	BraseroLibisofs *cobj;
+	BraseroLibisofsPrivate *priv;
 
 	cobj = BRASERO_LIBISOFS (object);
+	priv = BRASERO_LIBISOFS_PRIVATE (object);
 
 	brasero_libisofs_stop_real (cobj);
 	brasero_libisofs_clean_output (cobj);
 
+	if (priv->mutex) {
+		g_mutex_free (priv->mutex);
+		priv->mutex = NULL;
+	}
+
+	if (priv->cond) {
+		g_cond_free (priv->cond);
+		priv->cond = NULL;
+	}
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -953,7 +1004,7 @@ brasero_libisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_define (plugin,
 			       "libisofs",
-			       _("libisofs creates disc images from files"),
+			       _("Libisofs creates disc images from files"),
 			       "Philippe Rouquier",
 			       0);
 
@@ -962,7 +1013,7 @@ brasero_libisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 				  BRASERO_MEDIUM_CDRW|
 				  BRASERO_MEDIUM_DVDR|
 				  BRASERO_MEDIUM_DVDRW|
-				  BRASERO_MEDIUM_DVD_DL|
+				  BRASERO_MEDIUM_DUAL_L|
 				  BRASERO_MEDIUM_APPENDABLE|
 				  BRASERO_MEDIUM_HAS_AUDIO|
 				  BRASERO_MEDIUM_HAS_DATA,
@@ -973,7 +1024,7 @@ brasero_libisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 	brasero_plugin_set_flags (plugin,
 				  BRASERO_MEDIUM_DVDRW_PLUS|
 				  BRASERO_MEDIUM_RESTRICTED|
-				  BRASERO_MEDIUM_DVD_DL|
+				  BRASERO_MEDIUM_DUAL_L|
 				  BRASERO_MEDIUM_APPENDABLE|
 				  BRASERO_MEDIUM_CLOSED|
 				  BRASERO_MEDIUM_HAS_DATA,
@@ -985,6 +1036,7 @@ brasero_libisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 					 BRASERO_PLUGIN_IO_ACCEPT_PIPE,
 					 BRASERO_IMAGE_FORMAT_BIN);
 	input = brasero_caps_data_new (BRASERO_IMAGE_FS_ISO|
+				       BRASERO_IMAGE_ISO_FS_DEEP_DIRECTORY|
 				       BRASERO_IMAGE_FS_JOLIET);
 
 	brasero_plugin_link_caps (plugin, output, input);
