@@ -51,6 +51,8 @@ struct _BraseroBurnURIPrivate {
 
 	guint thread_id;
 	GThread *thread;
+	GMutex *mutex;
+	GCond *cond;
 
 	GError *error;
 };
@@ -340,10 +342,15 @@ brasero_burn_uri_thread (gpointer data)
 
 end:
 
-	 if (!g_cancellable_is_cancelled (priv->cancel))
+	if (!g_cancellable_is_cancelled (priv->cancel))
 		priv->thread_id = g_idle_add ((GSourceFunc) brasero_burn_uri_thread_finished, self);
 
-	priv->thread = NULL;
+	/* End thread */
+	g_mutex_lock (priv->mutex);
+	g_atomic_pointer_set (&priv->thread, NULL);
+	g_cond_signal (priv->cond);
+	g_mutex_unlock (priv->mutex);
+
 	g_thread_exit (NULL);
 
 	return NULL;
@@ -360,10 +367,12 @@ brasero_burn_uri_start_thread (BraseroBurnURI *self,
 	if (priv->thread)
 		return BRASERO_BURN_RUNNING;
 
+	g_mutex_lock (priv->mutex);
 	priv->thread = g_thread_create (brasero_burn_uri_thread,
 					self,
 					TRUE,
 					error);
+	g_mutex_unlock (priv->mutex);
 	if (!priv->thread) 
 		return BRASERO_BURN_ERR;
 
@@ -465,7 +474,7 @@ brasero_burn_uri_start (BraseroJob *job,
 
 static BraseroBurnResult
 brasero_burn_uri_stop (BraseroJob *job,
-			  GError **error)
+		       GError **error)
 {
 	BraseroBurnURIPrivate *priv = BRASERO_BURN_URI_PRIVATE (job);
 
@@ -474,8 +483,10 @@ brasero_burn_uri_stop (BraseroJob *job,
 		g_cancellable_cancel (priv->cancel);
 	}
 
+	g_mutex_lock (priv->mutex);
 	if (priv->thread)
-		g_thread_join (priv->thread);
+		g_cond_wait (priv->cond, priv->mutex);
+	g_mutex_unlock (priv->mutex);
 
 	if (priv->cancel) {
 		/* unref it after the thread has stopped */
@@ -499,6 +510,18 @@ brasero_burn_uri_stop (BraseroJob *job,
 static void
 brasero_burn_uri_finalize (GObject *object)
 {
+	BraseroBurnURIPrivate *priv = BRASERO_BURN_URI_PRIVATE (object);
+
+	if (priv->mutex) {
+		g_mutex_free (priv->mutex);
+		priv->mutex = NULL;
+	}
+
+	if (priv->cond) {
+		g_cond_free (priv->cond);
+		priv->cond = NULL;
+	}
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -519,7 +542,12 @@ brasero_burn_uri_class_init (BraseroBurnURIClass *klass)
 
 static void
 brasero_burn_uri_init (BraseroBurnURI *obj)
-{ }
+{
+	BraseroBurnURIPrivate *priv = BRASERO_BURN_URI_PRIVATE (obj);
+
+	priv->mutex = g_mutex_new ();
+	priv->cond = g_cond_new ();
+}
 
 static BraseroBurnResult
 brasero_burn_uri_export_caps (BraseroPlugin *plugin, gchar **error)
@@ -527,8 +555,11 @@ brasero_burn_uri_export_caps (BraseroPlugin *plugin, gchar **error)
 	GSList *caps;
 
 	brasero_plugin_define (plugin,
-			       "burn_uris",
-			       _("Burn_uri allows burning files added to \"CD/DVD Creator Folder\" in nautilus"),
+			       /* Translators: this is the name of the plugin
+				* which will be translated only when it needs
+				* displaying. */
+			       N_("CD/DVD Creator Folder"),
+			       _("Allows to burn files added to \"CD/DVD Creator Folder\" in nautilus"),
 			       "Philippe Rouquier",
 			       11);
 
